<?php

namespace GRIDBUILDERX;

if (!defined('ABSPATH')) {
    exit;
}

final class Ajax_Callbacks
{

    //singleton instance
    private static $instance = null;

    // get the instance
    public static function get_instance()
    {

        if (null == self::$instance) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    public function __construct()
    {

        // load the dependencies
        $this->load_dependencies();

        add_action('wp_ajax_grid_builder_x', array($this, 'grid_builder_x'));
        add_action('wp_ajax_nopriv_grid_builder_x', array($this, 'grid_builder_x'));

        //gbx_select_taxonomy_control
        add_action('wp_ajax_gbx_select_taxonomy_control', array($this, 'gbx_select_taxonomy_control_callback'));
        add_action('wp_ajax_nopriv_gbx_select_taxonomy_control', array($this, 'gbx_select_taxonomy_control_callback'));


        //gbx_select_taxonomy_control_in filters
        add_action('wp_ajax_gbx_select_taxonomy_control_filter', array($this, 'gbx_select_taxonomy_control__filter_callback'));
        add_action('wp_ajax_nopriv_gbx_select_taxonomy_control_filter', array($this, 'gbx_select_taxonomy_control__filter_callback'));

        // gbx_select_post_control
        add_action('wp_ajax_gbx_select_search_posts_control', array($this, 'gbx_select_post_control_callback'));
        add_action('wp_ajax_nopriv_gbx_select_search_posts_control', array($this, 'gbx_select_post_control_callback'));
    }


    // load the dependencies
    private function load_dependencies()
    {
        // load the query builder
        require_once plugin_dir_path(dirname(__FILE__)) . 'class/query-builder.php';
    }

    public function gbx_select_taxonomy_control__filter_callback()
    {
        check_ajax_referer('gbx-filter-taxonomy-control-nonce', 'nonce');
        $args = array(
            'hide_empty' => false,
            'fields' => 'id=>name',
        );
        if (isset($_REQUEST['taxonomy'])) {
            $args['taxonomy'] = esc_html($_REQUEST['taxonomy']);
        }
        $terms = get_terms($args);
        $response  = [];
        foreach ($terms as $key => $term) {
            $response[] = [
                'id' => $key . '|' . $term,
                'text' => $term,
                'title' => $term,
                'taxonomy' => $_REQUEST['taxonomy'],
            ];
        }
        wp_send_json($response);
        wp_die();
    }

    public function gbx_select_taxonomy_control_callback()
    {
        check_ajax_referer('gbx-ags-control-nonce', 'nonce');
        $args = array(
            'hide_empty' => false,
            'fields' => 'id=>name',
        );
        if (isset($_REQUEST['taxonomy'])) {
            $args['taxonomy'] = esc_html($_REQUEST['taxonomy']);
        }
        $terms = get_terms($args);
        $response  = [];
        foreach ($terms as $key => $term) {
            $response[] = [
                'id' => $key . '|' . $term,
                'text' => $term,
                'title' => $term,
                'taxonomy' => $_REQUEST['taxonomy'],
            ];
        }
        wp_send_json($response);
        wp_die();
    }

    public function gbx_select_post_control_callback()
    {
        check_ajax_referer('gbx-search-posts-nonce', 'nonce');
        $post_types = get_post_types();


        $args = array(
            'post_type' => $post_types,
            'posts_per_page' => 15,
            's' => sanitize_text_field($_REQUEST['search']),
            'exact'          => true,
            'sentence'       => true,
        );


        $posts = get_posts($args);
        $response  = [];
        foreach ($posts as $post) {
            $response[] = [
                'id' => $post->ID . '|' . $post->post_title,
                'text' => $post->post_title,
                'title' => $post->post_title,
            ];
        }
        wp_send_json($response);
        wp_die();
    }

    private function custom_sanitize($value)
    {
        if (is_array($value)) {
            return array_map(array($this, 'custom_sanitize'), $value);
        } else {
            $sanitized_value = sanitize_text_field($value);

            if ($sanitized_value === '&lt;') {
                return '<';
            }

            if ($sanitized_value === '&lt;=') {
                return '<=';
            }

            return $sanitized_value;
        }
    }

    private function get_and_sanitize_filter($filter_key)
    {
        $filter = isset($_POST[$filter_key]) ? $_POST[$filter_key] : '{}';
        if ($filter != '{}' && $filter != '') {
            $filter = json_decode(stripslashes($filter), true);
            $filter = array_map(array($this, 'custom_sanitize'), $filter);
        }
        return $filter;
    }

    public function grid_builder_x()
    {
        // check the nonce
        check_ajax_referer('gbx-nonce', 'nonce');

        // Get and sanitize filters
        $taxonomy_filters = $this->get_and_sanitize_filter('taxonomy_filter');
        $search_filter = $this->get_and_sanitize_filter('search_filter');
        $meta_filter = $this->get_and_sanitize_filter('meta_filter');
        $order_by = $this->get_and_sanitize_filter('order_filter');


        // get the connector
        $connector = isset($_POST['connector']) ? sanitize_text_field($_POST['connector']) : '';
        $page = isset($_POST['page']) ? sanitize_text_field($_POST['page']) : 1;


        $args = $this->get_and_sanitize_filter('args');
        $args['paged'] = $page;

        if (isset($search_filter[0]['s'])) {
            $args['gbx_search_prod_title'] = $search_filter[0]['s'];
        }

        if (!empty($taxonomy_filters)) {
            if (isset($args['tax_query'])) {
                $args['tax_query']['relation'] = 'AND';
                foreach ($taxonomy_filters as $filter) {
                    $args['tax_query'][] = $filter;
                }
            } else {
                $args['tax_query'] = $taxonomy_filters;
            }
        }



        if (!empty($meta_filter)) {
            if (isset($args['meta_query'])) {
                $args['meta_query']['relation'] = 'AND';
                foreach ($meta_filter as $filter) {
                    $args['meta_query'][] = $filter;
                }
            } else {
                $args['meta_query'] = $meta_filter;
            }
        }

        if (!empty($order_by)) {

            if (isset($order_by[0]['orderby'])) {
                $args['orderby'] = $order_by[0]['orderby'];
            }

            if (isset($order_by[0]['order'])) {
                $args['order'] = $order_by[0]['order'];
            }

            if (isset($order_by[0]['metaKey'])) {
                $args['meta_key'] = $order_by[0]['metaKey'];
            }

            if (isset($order_by[0]['metaType'])) {
                $args['meta_type'] = $order_by[0]['metaType'];
            }
        }


        $query = new Query_Builder($args, $connector);
        $layout = isset($_POST['layout']) ? sanitize_text_field($_POST['layout']) : '{}';
        $layout = json_decode(stripslashes($layout), true);
        $query->the_posts($layout);
        echo '|max_pages:' . intval($query->maximum_posts);
        wp_die();
    }
}


// instantiate the class
Ajax_Callbacks::get_instance();
