<?php

namespace GRIDBUILDERX;

if (!defined('ABSPATH')) {
    exit;
}

class Arg_Builder
{
    public $args = array();
    public $settings;

    // constructor
    public function __construct($settings)
    {
        $this->settings = $settings;

        $this->generate_args();
    }

    // posts per page
    public function posts_per_page()
    {
        $this->args['posts_per_page'] = $this->settings['gbx_posts_per_page'];
    }

    // post type
    public function post_type()
    {
        $this->args['post_type'] = $this->settings['gbx_post_type'];
    }

    // order by
    public function order_by()
    {
        $this->args['orderby'] = $this->settings['gbx_order_by'];
    }

    // order
    public function order()
    {
        $this->args['order'] = $this->settings['gbx_order'];
    }

    // meta key
    public function meta_key()
    {
        $this->args['meta_key'] = $this->settings['gbx_meta_key'];
    }

    // meta type
    public function meta_type()
    {
        $this->args['meta_type'] = $this->settings['gbx_meta_type'];
    }

    // meta compare
    public function meta_compare()
    {
        $this->args['meta_compare'] = $this->settings['gbx_meta_compare'];
    }

    // author
    public function author()
    {
        $this->args['author'] = $this->settings['gbx_author'];
    }

    // post status
    public function post_status()
    {
        $this->args['post_status'] = $this->settings['gbx_post_status'];
    }

    // password protected
    public function password_protected()
    {
        $pass_proteched = $this->settings['gbx_password_protected'];
        if ($pass_proteched == 'no') {
            $this->args['has_password'] = false;
        } else {
            $this->args['has_password'] = true;
        }
    }

    // offset
    public function offset()
    {
        $this->args['offset'] = $this->settings['gbx_offset'];
    }

    // exclude
    public function exclude()
    {
        if (!empty($this->settings['gbx_exclude_posts'])) {
            $stringVal = $this->settings['gbx_exclude_posts'];
            $stringVal = str_replace(array('[', ']'), '', $stringVal);
            $stringVal = str_replace(array('"'), '', $stringVal);
            $exclude_posts = explode(',', $stringVal);

            if (empty($exclude_posts[0])) {
                return;
            }

            $options = array();
            foreach ($exclude_posts as $key => $value) {
                $options[] = explode('|', $value)[0];
            }
            $this->args['post__not_in'] = $options;
        }
    }

    // include
    public function include()
    {
        if (!empty($this->settings['gbx_include_posts'])) {
            $stringVal = $this->settings['gbx_include_posts'];
            $stringVal = str_replace(array('[', ']'), '', $stringVal);
            $stringVal = str_replace(array('"'), '', $stringVal);
            $include_posts = explode(',', $stringVal);

            if (empty($include_posts[0])) {
                return;
            }

            $options = array();
            foreach ($include_posts as $key => $value) {
                $options[] = explode('|', $value)[0];
            }
            $this->args['post__in'] = $options;
        }
    }

    // search keyword
    public function search_keyword()
    {
        $this->args['s'] = $this->settings['gbx_search_posts'];
    }

    private function generate_nested_array_tax_query($arr)
    {
        $result = array();
        if ($arr) {
            foreach ($arr as $key => $element) {
                if ($element['gbx_tax_query_relation_or_taxonomy'] == 'relation') {
                    $result[]['relation'] = $element['gbx_tax_query_relation'];
                } else {
                    $json_tax_query_sub_item = json_decode($element['gbx_tax_query_taxonomy'], true);
                    $items  = $json_tax_query_sub_item['gbx-arg-group-a'];
                    $operator = $element['gbx_tax_query_operator'];
                    foreach ($items as $key => $item) {
                        $terms = array();
                        foreach ($item['taxonomyterms'] as $key_term => $term) {
                            $terms[] = explode('|', $term)[0];
                        }
                        $result[] = array(
                            'taxonomy' => $item['taxonomy'],
                            'field' => 'term_id',
                            'terms' => $terms,
                            'operator' => $operator,
                        );
                    }
                }
            }
        }

        $ref = array();
        $result_ref = &$ref;
        foreach ($result as $row) {
            if (key($row) !== 'relation') { // populate current level
                $ref[] = $row; // push color into reference
                continue;
            }
            if ($ref) {  // not the first relation encountered
                // set $ref to point to new deeper subarray
                $ref = &$ref[count($ref) - 1];
            }
            $ref = $row; // push relation
        }

        return $result_ref;
    }

    // tax query
    public function tax_query()
    {
        if (!empty($this->settings['gbx_repeater_tax_query_builder'])) {
            $arr = $this->settings['gbx_repeater_tax_query_builder'];
            $this->args['tax_query'] = $this->generate_nested_array_tax_query($arr);
        }
    }


    private function generate_nested_array_metaquery($arr)
    {
        $result = array();
        if ($arr) {
            foreach ($arr as $key => $element) {
                if ($element['gbx_meta_query_relation_or_meta_key'] == 'relation') {
                    $result[]['relation'] = $element['gbx_meta_query_relation'];
                } else {
                    $check_valid = array(
                        'key' => $element['gbx_meta_query_meta_key'],
                        'value' => $element['gbx_meta_query_meta_value'],
                        'compare' => $element['gbx_meta_query_meta_compare'],
                        'type' => $element['gbx_meta_query_meta_type'],
                    );

                    // check if any of the value is empty
                    $check_empty = array_filter($check_valid, function ($value) {
                        return $value !== '';
                    });

                    if (count($check_empty) == 4) {
                        $result[] = $check_valid;
                    }
                }
            }
        }

        $ref = array();
        $result_ref = &$ref;
        foreach ($result as $row) {
            if (key($row) !== 'relation') { // populate current level
                $ref[] = $row; // push color into reference
                continue;
            }
            if ($ref) {  // not the first relation encountered
                // set $ref to point to new deeper subarray
                $ref = &$ref[count($ref) - 1];
            }
            $ref = $row; // push relation
        }

        return $result_ref;
    }


    // meta query
    public function meta_query()
    {
        if (!empty($this->settings['gbx_repeater_meta_query_builder'])) {
            $arr = $this->settings['gbx_repeater_meta_query_builder'];
            $this->args['meta_query'] = $this->generate_nested_array_metaquery($arr);
        }
    }

    // a private function to conver the string to number if not valid then return ''
    private function convert_to_number($string)
    {
        //intval
        $string  = intval($string);

        if (is_numeric($string)) {
            return $string;
        } else {
            return '';
        }
    }

    private function generate_nested_array_date_query($arr)
    {
        $result = array();
        if ($arr) {
            foreach ($arr as $key => $element) {
                if ($element['gbx_date_query_type'] == 'relation') {
                    $result[]['relation'] = $element['gbx_date_query_relation'];
                } else {

                    $inclusive_data  = $element['gbx_date_query_inclusive'];


                    if ($inclusive_data == 'yes') {
                        $inclusive = true;
                    } else {
                        $inclusive = false;
                    }

                    $data = array(
                        // 'year' => $element['gbx_date_query_year'],
                        'month' => $element['gbx_date_query_month'],
                        'week' => $element['gbx_date_query_week'],
                        'day' => $element['gbx_date_query_day'],
                        'hour' => $element['gbx_date_query_hour'],
                        'minute' => $element['gbx_date_query_minute'],
                        'second' => $element['gbx_date_query_second'],
                        'compare' => $element['gbx_date_query_compare'],
                        'column' => $element['gbx_date_query_column'],
                        'after' => $element['gbx_date_query_before_after_string_after'],
                        'before' => $element['gbx_date_query_before_after_string_before'],
                        'inclusive' => $inclusive,
                    );
                    // remvoe empty value in the $data array
                    $data = array_filter($data);
                    $result[] = $data;
                }
            }
        }

        $ref = array();
        $result_ref = &$ref;
        foreach ($result as $row) {
            if (key($row) !== 'relation') { // populate current level
                $ref[] = $row; // push color into reference
                continue;
            }
            if ($ref) {  // not the first relation encountered
                // set $ref to point to new deeper subarray
                $ref = &$ref[count($ref) - 1];
            }
            $ref = $row; // push relation
        }

        return $result_ref;
    }

    // date query
    public function date_query()
    {
        if (!empty($this->settings['gbx_date_query'])) {
            $arr = $this->settings['gbx_date_query'];
            $this->args['date_query'] = $this->generate_nested_array_date_query($arr);
        }
    }


    // generate args
    public function generate_args()
    {
        $this->posts_per_page();
        $this->post_type();
        $this->order_by();
        $this->order();
        $this->meta_key();
        $this->meta_type();
        $this->meta_compare();
        $this->author();
        $this->post_status();
        $this->password_protected();
        $this->offset();
        $this->exclude();
        $this->include();
        $this->search_keyword();
        $this->tax_query();
        $this->meta_query();
        $this->date_query();
        return $this->args;
    }

    // get args
    public function get_args()
    {
        //remove empty keys
        $this->args = array_filter($this->args);

        return $this->args;
    }
}
