<?php

namespace GRIDBUILDERX;

if (!defined('ABSPATH')) {
    exit;
}

class Query_Builder
{

    public $args = array();
    public $connector = 0;
    public $maximum_posts = 0;
    public $query = null;

    public function __construct($args, $connector)
    {
        $this->args = $args;
        $this->connector = $connector;

        $this->query = $this->get_query();
        $this->maximum_posts = $this->query->max_num_pages;
    }

    public function get_query()
    {
        return new \WP_Query($this->args);
    }

    public function max_num_pages()
    {
        return $this->get_query()->max_num_pages;
    }

    // total number of posts
    public function found_posts()
    {
        return $this->get_query()->found_posts;
    }

    private function background_generator($layout)
    {
        if ((!isset($layout['background']['type'])) || (empty($layout['background']['type']))) {
            return '';
        }

        $background = '';

        switch ($layout['background']['type']) {
            case 'featured_image':
                $attachment_id = get_post_thumbnail_id(get_the_ID());


                // handle the placeholder
                if (empty($attachment_id)) {
                    $background = $layout['background']['paceholder']['url'];
                    return $background;
                }

                $settings = array(
                    'gbx_grid_background_placeholder' => $layout['background']['paceholder']['url'],
                    'gbx_grid_background_placeholder_size' => $layout['background']['size'],
                );

                if (isset($layout['background']['custom_size'])) {
                    $settings['gbx_grid_background_placeholder_custom_dimension'] = $layout['background']['custom_size'];
                }

                $image_url = Gbx_Featurred_Image_Getter::get_attachment_image_src($attachment_id, 'gbx_grid_background_placeholder',  $settings);

                return $image_url;
                break;
            case 'acf':
                //check if acf is installed using the class
                if (!class_exists('ACF')) {
                    break;
                }

                $acfkey = $layout['background']['field'];
                if (is_array($acfkey)) {
                    return '';
                }
                $image_url = get_field($acfkey, get_the_ID());

                if (is_array($image_url)) {
                    $image_url = $image_url['url'];
                } elseif (is_numeric($image_url)) {
                    $image_url = wp_get_attachment_image_src($image_url, 'full');
                    if (isset($image_url[0])) {
                        $image_url = $image_url[0];
                    }
                } elseif (is_string($image_url)) {
                    $image_url = $image_url;
                } else {
                    $image_url = $layout['background']['paceholder']['url'];
                }

                return $image_url;
                break;
            default:
                $background = $layout['background']['paceholder'];
                break;
        }

        return $background;
    }


    // loop through the posts
    public function the_posts($layout)
    {
        $query = $this->query;
        $new_layout = array();
        $temp_array = array();



        foreach ($layout['fields'] as $key => $field) {
            if ($field['field_type'] == 'column') {
                if (!empty($temp_array)) {
                    $new_layout[] = $temp_array;
                    $temp_array = array();
                }
            }

            $temp_array[] = $field;
        }

        if (!empty($temp_array)) {
            $new_layout[] = $temp_array;
        }

        if ($query->have_posts()) {
            $i = 0;
            while ($query->have_posts()) {
                // the post title
                $query->the_post();
                $background = $this->background_generator($layout);
                $background_style = '';
                if (!empty($background)) {
                    $background_style .= 'background-image:url(' . $background . ');';
                }
                $link = '';
                if (isset($layout['clickable'])) {

                    switch ($layout['clickable']['type']) {
                        case 'post':
                            $link = get_the_permalink();
                            break;
                        case 'custom':
                            $link = $layout['clickable'];
                            break;
                        case 'acf':
                            //check if acf is installed using the class
                            if (!class_exists('ACF')) {
                                break;
                            }
                            if (!isset($layout['clickable']['acffield'])) {
                                break;
                            }
                            $link = get_field($layout['clickable']['acffield'], get_the_ID());
                            // check if the valid link
                            if (!filter_var($link, FILTER_VALIDATE_URL)) {
                                break;
                            }
                            break;
                        default:
                            $link = get_the_permalink();
                            break;
                    }
                }

                // $class_animation = 'grid__item__animated';
                $target = '_self';
                if ($link != '') {
                    $background_style .= 'cursor:pointer;';
                    if (isset($layout['clickable']['target']) && $layout['clickable']['target'] == '_blank') {
                        $target = '_blank';
                    }
                }
?>
                <div class="gbx-outer" <?php echo esc_html($this->schemea_data_generator($layout, 'schema', 'type', "schema")); ?> <?php echo esc_html($this->schemea_data_generator($layout, 'schema', 'organization_name', "name")); ?> <?php echo esc_html($this->schemea_data_generator($layout, 'schema', 'organization_logo', "logo")); ?> <?php echo esc_html($this->schemea_data_generator($layout, 'schema', 'organization_url', "url")); ?>>
                    <div data-target="<?php echo $target; ?>" data-postid="<?php echo get_the_ID(); ?>" data-link="<?php echo !empty($link) ?  esc_url($link) : esc_html($link); ?>" class="gbx-post-<?php echo $layout['idofgrid'] ?>-<?php echo get_the_ID(); ?>  grid__item__animated gbx__item" style="<?php echo $background_style;  ?>">
                        <?php
                        foreach ($new_layout as $block) {

                            if (isset($block[0]['field_type']) && $block[0]['field_type'] == 'column') {
                                $repeater_id = $block[0]['_id'];
                                echo '<div class="gbx__block  elementor-repeater-item-' . esc_attr($repeater_id) . '">';
                            } else {
                                echo '<div class="gbx__block">';
                            }
                            foreach ($block as $field) {
                                $this->field_switcher($field);
                            }
                            echo '</div>';
                        }
                        ?>
                    </div>
                </div>
<?php

                $i++;
            }

            wp_reset_postdata();
        }
    }

    private function schemea_data_generator($layout, $title, $value, $data)
    {
        if (isset($layout['schema']['enable']) && $layout['schema']['enable'] == 1) {
            if (isset($layout[$title][$value])) {
                return "data-" . $data . "=" . $layout[$title][$value];
            }
        }
    }

    private function field_switcher($field)
    {
        require_once GBX_PLUGIN_DIR . 'utils/class-field-generator.php';
        $field_generator = new Field_Generator($field);
        $field_generator->render();
    }
}
