<?php

namespace GRIDBUILDERX;

if (!defined('ABSPATH')) {
    exit;
}


class Field_Generator
{
    public $layout;

    public function __construct($field)
    {
        $this->layout = new Layout($field);
    }


    public function wrapper_start($custom_class = '')
    {
        if (isset($this->layout->config['enable_hover_visibility'])) {
            $data_visibility = $this->layout->config['enable_hover_visibility'];
        } else {
            $data_visibility = '';
        }
        $data_rating_class = '';
        $data_schema_property = '';
        $data_schema_property_type = '';
        $data_schema_rating_count = 1;
        if (isset($this->layout->config['schema_property']) && $this->layout->config['schema_property'] != 'none') {
            $data_schema_property = $this->layout->config['schema_property'];
            if ($data_schema_property == 'other') {
                if (isset($this->layout->config['other_schema_property'])) {
                    $data_schema_property = $this->layout->config['other_schema_property'];
                }
                if (isset($this->layout->config['type_schema_property'])) {
                    $data_schema_property_type = $this->layout->config['type_schema_property'];
                }
            }
        }
        echo '<' . esc_attr($this->layout->wrapper_tag) . ' data-visibility="' . esc_attr($data_visibility) . '" data-schema-property="' . esc_attr($data_schema_property) . '" data-schema-type="' . esc_attr($data_schema_property_type) . '" data-rating-count="' . esc_attr($data_schema_rating_count) . '" class="elementor-repeater-item-' . esc_attr($this->layout->_id) . ' gbx-repeater-item ' . esc_attr($custom_class) . '  " >';
        echo  '<div class="gbx-repeater-item-inner">';
    }

    public function wrapper_end()
    {
        echo '</div>';
        echo '</' . esc_attr($this->layout->wrapper_tag) . '>';
    }

    public function render_icon($position)
    {
        $type = $position . '_type';

        // switch for icon, text, html
        switch ($this->layout->config[$type]) {

            case "text":

                $text = $position . '_text';
                $value = $this->layout->config[$text];

                echo "<span class='gbx__" . esc_attr($position) . " gbx__" . esc_attr($position) . "-" . esc_attr($this->layout->_id) . "'>" . esc_html__($value) . "</span>";
                break;
            case "icon":
                $icon = $position . '_icon';

                if (empty($this->layout->config[$icon])) {
                    break;
                }
                $icon_a = $this->layout->config[$icon];

                echo "<span class='gbx-" . esc_attr($position) . "-icon gbx__" . esc_attr($position) . "-" . esc_attr($this->layout->_id) . "'>";
                \Elementor\Icons_Manager::render_icon($icon_a, ['aria-hidden' => 'true', 'class' => 'gbx-in-' . esc_attr($position) . '-icon gbx__in__' . esc_attr($position) . '-icon gbx__in__' . esc_attr($position) . '-icon-' . esc_attr($this->layout->_id) . ' ' . esc_attr($this->layout->custom_class)], 'i');
                echo "</span>";
                break;
            case "html":
                $html = $position . '_html';

                if (empty($this->layout->config[$html])) {
                    break;
                }
                $value = $this->layout->config[$html];
                echo "<span class='gbx__" . esc_attr($position) . " gbx__" . esc_attr($position) . "-" . esc_attr($this->layout->_id) . "'>" . wp_kses_post($value) . "</span>";

                break;

            default:
                break;
        }
    }

    private function renderRatingIcons($value)
    {
        if (isset($this->layout->config['is_rating']) && $this->layout->config['is_rating'] == 'yes') {
            $rating = intval($value);
            if (isset($this->layout->config['rating_icons'])) {
                $icon_a = $this->layout->config['rating_icons'];
                // for loop for rating 
                for ($i = 0; $i < $rating; $i++) {
                    \Elementor\Icons_Manager::render_icon($icon_a, ['aria-hidden' => 'true', 'class' => 'gbx-icon-' . esc_attr($this->layout->_id) . ' ' . esc_attr($this->layout->custom_class)], 'i');
                }
            }
            return true;
        } else {
            return false;
        }
    }

    public function main_render_text()
    {
        switch ($this->layout->config['kind']) {
            case 'title':
                // enable excerpt trim
                $enable_trim = $this->layout->config['enable_excerpt_trim'];
                if ($enable_trim == 'yes') {
                    $excerpt_length = $this->layout->config['excerpt_length'];
                    echo esc_html__(wp_trim_words(get_the_title(), $excerpt_length));
                } else {
                    echo esc_html__(get_the_title());
                }
                break;
            case 'plain_text':
                if ($this->renderRatingIcons($this->layout->config['plain_text'])) {
                    break;
                }
                echo esc_html__($this->layout->config['plain_text']);
                break;
            case 'content':
                $enable_trim = isset($this->layout->config['enable_excerpt_trim']) ? $this->layout->config['enable_excerpt_trim'] : '';
                if ($enable_trim == 'yes') {
                    $excerpt_length = isset($this->layout->config['excerpt_length']) ? $this->layout->config['excerpt_length'] : '';
                    echo wp_trim_words(strip_tags(get_the_content()), $excerpt_length);
                } else {
                    echo strip_tags(get_the_content());
                }
                break;
            case 'excerpt':
                $enable_trim = isset($this->layout->config['enable_excerpt_trim']) ? $this->layout->config['enable_excerpt_trim'] : '';
                if ($enable_trim == 'yes') {
                    $excerpt_length = isset($this->layout->config['excerpt_length']) ? $this->layout->config['excerpt_length'] : '';
                    echo esc_html__(wp_trim_words(get_the_excerpt(), $excerpt_length));
                } else {
                    echo esc_html__(get_the_excerpt());
                }
                break;
            case 'custom':
                if (!isset($this->layout->config['custom_field_key_text']) || empty($this->layout->config['custom_field_key_text'])) {
                    break;
                }
                $enable_trim = isset($this->layout->config['enable_excerpt_trim']) ? $this->layout->config['enable_excerpt_trim'] : '';
                $custom_post_key = isset($this->layout->config['custom_field_key_text']) ? $this->layout->config['custom_field_key_text'] : '';

                if ($enable_trim == 'yes') {
                    $excerpt_length = isset($this->layout->config['excerpt_length']) ? $this->layout->config['excerpt_length'] : '';
                    echo esc_html__(wp_trim_words(get_post_meta(get_the_ID(), $custom_post_key, true), $excerpt_length));
                } else {

                    if ($this->renderRatingIcons(get_post_meta(get_the_ID(), $custom_post_key, true))) {
                        break;
                    }
                    echo esc_html__(get_post_meta(get_the_ID(), $custom_post_key, true));
                }
                break;
            case 'acf':
                //check if acf is active
                if (!class_exists('ACF')) {
                    break;
                }
                $enable_trim = isset($this->layout->config['enable_excerpt_trim']) ? $this->layout->config['enable_excerpt_trim'] : '';
                $excerpt_length = isset($this->layout->config['excerpt_length']) ? $this->layout->config['excerpt_length'] : '';
                $acf_field_key = isset($this->layout->config['acf_field_key']) ? $this->layout->config['acf_field_key'] : '';
                $is_inside_group = isset($this->layout->config['is_inside_group']) ? $this->layout->config['is_inside_group'] : '';
                $acf_group_key = isset($this->layout->config['group_field_key']) ? $this->layout->config['group_field_key'] : '';
                $place_holder = isset($this->layout->placeholder) ? $this->layout->placeholder : '';
                if ($is_inside_group == 'yes') {
                    $acf_field_key = $acf_group_key . '_' . $acf_field_key;
                }
                if (isset($this->layout->config['is_rating']) && $this->layout->config['is_rating'] == 'yes') {
                    $rating = get_field($acf_field_key, get_the_ID());
                    $rating = intval($rating);
                    if (isset($this->layout->config['rating_icons'])) {
                        $icon_a = $this->layout->config['rating_icons'];
                        // for loop for rating 
                        for ($i = 0; $i < $rating; $i++) {
                            \Elementor\Icons_Manager::render_icon($icon_a, ['aria-hidden' => 'true', 'class' => 'gbx-icon-' . esc_attr($this->layout->_id) . ' ' . esc_attr($this->layout->custom_class)], 'i');
                        }
                    }
                    break;
                }
                if ($this->renderRatingIcons(get_field($acf_field_key, get_the_ID()))) {
                    break;
                }
                $field_value = get_field($acf_field_key, get_the_ID());
                if ($enable_trim == 'yes') {
                    $field_value = wp_trim_words($field_value, $excerpt_length);
                }

                if (is_string($field_value)) {
                    if (empty($field_value) && !empty($place_holder)) {
                        echo esc_html__($place_holder);
                    } else {
                        echo esc_html__($field_value);
                    }
                } else {
                    // if admin only
                    if (current_user_can('administrator')) {
                        echo esc_html__("Not a valid ACF key", "gbx");
                    }
                }
                break;
            case 'woocommerce':
                //check if woocommerce is active
                if (!class_exists('WooCommerce')) {
                    break;
                }

                $woocommerce_field_key = isset($this->layout->config['woocommerce_field_type']) ? $this->layout->config['woocommerce_field_type'] : '';
                $enable_trim = isset($this->layout->config['enable_excerpt_trim']) ? $this->layout->config['enable_excerpt_trim'] : '';
                $excerpt_length = isset($this->layout->config['excerpt_length']) ? $this->layout->config['excerpt_length'] : '';

                $product = wc_get_product(get_the_ID());

                if ($product) {

                    switch ($woocommerce_field_key) {
                        case 'sku':
                            echo esc_html($product->get_sku() ? $product->get_sku() : '');
                            break;
                        case 'stock':
                            echo esc_html($product->get_stock_quantity() ? $product->get_stock_quantity() : '');
                            break;
                        case 'rating':
                            $rating = $product->get_average_rating();
                            if ($this->renderRatingIcons($rating)) {
                                break;
                            }
                            if ($rating) {
                                echo $this->custom_wc_get_rating_html($rating);
                            }
                            break;

                        case 'sale_price':
                            echo ($product->get_sale_price()) ? wp_kses_post(wc_price($product->get_sale_price())) : '';
                            break;
                        case 'regular_price':
                            echo wp_kses_post(wc_price($product->get_regular_price()));
                            break;
                        case 'sale_percentage':
                            $percentage = ($product->get_sale_price()) ? round((($product->get_regular_price() - $product->get_sale_price()) / $product->get_regular_price()) * 100) : 0;
                            echo esc_html($percentage . '%');
                            break;
                        case 'price':
                            // echo price html by wpkses
                            echo wp_kses_post($product->get_price_html());
                            break;
                        case 'price_range':
                            echo esc_html($product->get_price_html());
                            break;
                        case 'summary':
                            // handle the trim
                            if ($enable_trim == 'yes') {
                                echo esc_html(wp_trim_words($product->get_short_description(), $excerpt_length));
                            } else {
                                echo esc_html($product->get_short_description());
                            }
                            break;
                        case 'description':
                            // handle the trim
                            if ($enable_trim == 'yes') {
                                echo esc_html(wp_trim_words($product->get_description(), $excerpt_length));
                            } else {
                                echo esc_html($product->get_description());
                            }
                            break;

                        default:
                            # code...
                            break;
                    }
                }
        }
    }


    private function custom_wc_get_rating_html($rating, $count = 0)
    {
        $html = '';
        $rating = floatval($rating);
        if ($rating > 0) {
            $star_output = '<div class="gbx-star-rating" role="img" aria-label="' . sprintf(__('Rated %s out of 5', 'woocommerce'), $rating) . '">';
            for ($i = 1; $i <= 5; $i++) {
                $star_output .= '<span class="gbx-star ' . ($i <= $rating ? 'filled' : '') . '">&#9733;</span>';
            }
            $star_output .= '</div>';
            $html = $star_output;
        }
        return $html;
    }



    public function main_render_image()
    {

        // switch cases to handdle featured, custom, acf
        switch ($this->layout->config['kind']) {
            case 'featured':


                $attachment_id = get_post_thumbnail_id(get_the_ID());

                $settings = array(
                    "grid_image" => $this->layout->config['grid_image'],
                    "grid_image_size" => $this->layout->config['grid_image_size'],
                );

                // check if isset the "grid_image_custom_dimension" the append it to the settings
                if (isset($this->layout->config['grid_image_custom_dimension'])) {
                    $settings['grid_image_custom_dimension'] = $this->layout->config['grid_image_custom_dimension'];
                }

                $image_url = Gbx_Featurred_Image_Getter::get_attachment_image_html_generator($attachment_id, $settings, $image_size_key = 'grid_image', $image_key = null, $extra = "");


                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '<a href="' . wp_get_attachment_url($attachment_id) . '" class="gbx-image-lightbox">';
                }

                echo $image_url;
                echo '<div class="gbx-overlay-image"></div>';

                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '</a>';
                }


                break;
            case 'custom':

                # check  $this->layout->config['custom_field_key'] is not empty
                if (empty($this->layout->config['custom_field_key_image'])) {
                    break;
                }


                $image_url = get_post_meta(get_the_ID(), $this->layout->config['custom_field_key_image'], true);
                $attachment_id = attachment_url_to_postid($image_url);



                $data = array(
                    "url" => $image_url,
                    "id" => $attachment_id,
                );

                $settings = array(
                    "grid_image" => $this->layout->config['grid_image'],
                    "grid_image_size" => $this->layout->config['grid_image_size'],
                    "grid_image_custom_dimension" =>   $this->layout->config['grid_image_custom_dimension'],
                );

                $image_html = Gbx_Featurred_Image_Getter::get_attachment_image_html_generator($attachment_id, $settings, $image_size_key = 'grid_image', $image_key = null, $extra = "");


                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '<a href="' . wp_get_attachment_url($attachment_id) . '" class="gbx-image-lightbox">';
                }

                echo Utils::sanitize_images_html($image_html);
                echo '<div class="gbx-overlay-image"></div>';

                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '</a>';
                }





                break;
            case 'acf':
                //echo layout

                // check if acf is active
                if (!class_exists('ACF')) {
                    break;
                }

                # check  $this->layout->config['acf_field_ke_image'] is not empty
                if (empty($this->layout->config['acf_field_key_image'])) {
                    break;
                }
                // handle all the cases above
                $image_url = get_field($this->layout->config['acf_field_key_image'], get_the_ID());

                if (is_array($image_url)) {
                    $attachment_id = $image_url['id'];
                } else if (is_string($image_url)) {
                    $attachment_id = attachment_url_to_postid($image_url);
                } else if (is_int($image_url)) {
                    $attachment_id = $image_url;
                } else if (isset($this->layout->config['grid_image']['id'])) {
                    $attachment_id = $this->layout->config['grid_image']['id'];
                } else {
                    $attachment_id = 0;
                }

                $data = array(
                    "url" => $image_url,
                    "id" => $attachment_id,
                );


                $settings = array(
                    "grid_image" => $this->layout->config['grid_image'],
                    "grid_image_size" => $this->layout->config['grid_image_size'],
                    // "grid_image_custom_dimension" =>   $this->layout->config['grid_image_custom_dimension'],
                );

                if (isset($this->layout->config['grid_image_custom_dimension'])) {
                    $settings['grid_image_custom_dimension'] = $this->layout->config['grid_image_custom_dimension'];
                }

                $image_html = Gbx_Featurred_Image_Getter::get_attachment_image_html_generator($attachment_id, $settings, $image_size_key = 'grid_image', $image_key = null, $extra = "");


                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '<a href="' . wp_get_attachment_url($attachment_id) . '" class="gbx-image-lightbox">';
                }

                echo Utils::sanitize_images_html($image_html);
                echo '<div class="gbx-overlay-image"></div>';

                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '</a>';
                }





                break;
            case 'author_image':

                $author_id = get_the_author_meta('ID');
                $attachment_id = get_field('profile_image', 'user_' . $author_id);
                $image_url = wp_get_attachment_url($attachment_id);

                $data = array(
                    "url" => $image_url,
                    "id" => $attachment_id,
                );

                $settings = array(
                    "grid_image" => $this->layout->config['grid_image'],
                    "grid_image_size" => $this->layout->config['grid_image_size'],
                    "grid_image_custom_dimension" => $this->layout->config['grid_image_custom_dimension'],
                );

                $image_html = Gbx_Featurred_Image_Getter::get_attachment_image_html_generator($attachment_id, $settings, $image_size_key = 'grid_image', $image_key = null, $extra = "");

                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '<a href="' . wp_get_attachment_url($attachment_id) . '" class="gbx-image-lightbox">';
                }
                echo Utils::sanitize_images_html($image_html);
                echo '<div class="gbx-overlay-image"></div>';
                if (isset($this->layout->config['enable_image_lightbox'])) {
                    echo '</a>';
                }



                break;
            default:
                break;
        }
    }

    public function main_render_meta()
    {
        switch ($this->layout->config['kind']) {
            case 'author':

                // get config
                if (isset($this->layout->config['field_value'])) {
                    $author_data_type = $this->layout->config['field_value'];

                    switch ($author_data_type) {
                        case 'display_name':
                            echo esc_html__(get_the_author_meta('display_name'));
                            break;
                        case 'first_name':
                            echo esc_html__(get_the_author_meta('first_name'));
                            break;
                        case 'last_name':
                            echo esc_html__(get_the_author_meta('last_name'));
                            break;
                        case 'user_login':
                            echo esc_html__(get_the_author_meta('user_login'));
                            break;
                        default:
                            break;
                    }
                }

                break;
            case 'date':

                $date_type = $this->layout->config['field_value'];

                // date format
                $date_format = $this->layout->config['date_format'];

                switch ($date_type) {
                    case 'post_date':
                        echo esc_html__(get_the_date($date_format));
                        break;
                    case 'post_modified':
                        echo esc_html__(get_the_modified_date($date_format));
                        break;
                }

                break;
            case 'categories':
                $taxonomy_name = $this->layout->config['field_value'];
                $number_of_terms = $this->layout->config['no_of_taxonomies'];
                $include_hierarchical = $this->layout->config['include_hierarchical'];
                $is_link = $this->layout->config['enable_link_terms'];
                $open_in_new_tab = $this->layout->config['open_term_links_in_new_tab'];
                $separator = $this->layout->config['separator'];

                $includes = $this->layout->config['include_terms'];
                $excludes = $this->layout->config['exclude_terms'];

                // convert comma separated string to array

                //check for null or single value
                // Convert comma-separated strings to arrays
                $includes = $includes ? explode(',', $includes) : array();
                $excludes = $excludes ? explode(',', $excludes) : array();

                $terms = get_the_terms(get_the_ID(), $taxonomy_name);

                if (is_array($terms) && !empty($terms)) {
                    // Filter out terms with parent terms if include_hierarchical is not set to 'yes'
                    if ($include_hierarchical !== 'yes') {
                        $terms = array_filter($terms, function ($term) {
                            return $term->parent == 0;
                        });
                    }

                    // Check if any terms match the includes or excludes
                    $included_terms = array_intersect($includes, array_map(function ($term) {
                        return $term->name;
                    }, $terms));
                    $excluded_terms = array_intersect($excludes, array_map(function ($term) {
                        return $term->name;
                    }, $terms));

                    // Filter out terms that match the exclude list
                    $terms = array_filter($terms, function ($term) use ($excluded_terms) {
                        return !in_array($term->name, $excluded_terms);
                    });

                    // If the include list is not empty, filter out terms that do not match the include list
                    if (!empty($included_terms)) {
                        $terms = array_filter($terms, function ($term) use ($included_terms) {
                            return in_array($term->name, $included_terms);
                        });
                    }

                    $terms = array_slice($terms, 0, $number_of_terms);

                    $terms = array_map(function ($term) use ($is_link, $open_in_new_tab) {
                        if ($is_link) {
                            $target = $open_in_new_tab ? 'target="_blank"' : '';
                            return '<a href="' . esc_url(get_term_link($term)) . '" ' . $target . '>' . esc_html($term->name) . '</a>';
                        } else {
                            return esc_html($term->name);
                        }
                    }, $terms);


                    echo implode($separator, $terms);
                }


                break;
            case 'comment':
                echo esc_html__(get_comments_number());
                break;
            case 'views':
                echo esc_html__(get_post_meta(get_the_ID(), 'views', true));
                break;
            default:
                break;
        }
    }

    public function main_render_utilities()
    {
        switch ($this->layout->config['kind']) {
            case 'divider':
                echo '<hr class="gbx-util-divider"></hr>';
                break;
            case 'icon':
                $position = "plain_icon";
                $icon_a = array();
                // parse the string to int    
                $icon_a["value"] =  $this->layout->config['field_value'];
                $icon_a["library"] =  $this->layout->config['library'];
                // get the icon
                \Elementor\Icons_Manager::render_icon($icon_a, ['aria-hidden' => 'true', 'class' => 'gbx-' . esc_attr($position) . '-icon gbx__' . esc_attr($position) . '-icon gbx__' . esc_attr($position) . '-icon-' . esc_attr($this->layout->_id) . ' ' . esc_attr($this->layout->custom_class)]);
                break;
            case 'shortcode':
                $shortcode_string = $this->layout->config['field_value'];
                if (!empty($shortcode_string) && strpos($shortcode_string, 'elementor-template') !== false) {
                    preg_match('/id="(\d+)"/', $shortcode_string, $matches);
                    if (isset($matches[1])) {
                        $template_id = (int) $matches[1];
                        if ($template_id > 0) {
                            echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display($template_id);
                        } else {
                            echo esc_html__('Invalid template ID.', 'gbx');
                        }
                    } else {
                        echo do_shortcode($this->layout->config['field_value']);
                    }
                } elseif (!empty($shortcode_string)) {
                    echo do_shortcode($this->layout->config['field_value']);
                } else {
                    echo esc_html__('No shortcode found.', 'gbx');
                }
                break;
            case 'html':
                // use kses to sanitize the html
                echo wp_kses_post($this->layout->config['field_value']);
                break;
            default:
                break;
        }
    }

    public function main_render_button()
    {
        # check $this->layout->config['open_in_new_tab'] is 'yes' then set target to _blank
        $target = $this->layout->config['open_in_new_tab'] == 'yes' ? 'target="_blank"' : '';

        $this->layout->config['custom_class'] = $this->layout->custom_class ? $this->layout->config['custom_class'] : '';

        switch ($this->layout->config['kind']) {
            case 'postlink':

                if ($this->layout->config["prefix_type"] == 'icon' || $this->layout->config["suffix_type"] == 'icon') {
                    echo "<a href='" . esc_url(get_the_permalink()) . "' class='gbx__button gbx__button-" . esc_attr($this->layout->_id) . " " . esc_attr($this->layout->config['custom_class']) . "' " . $target . ">";
                    $this->render_icon('prefix');
                    echo esc_html__($this->layout->config['button_text']);
                    $this->render_icon('suffix');
                    echo "</a>";
                } else {
                    echo "<a href='" . esc_url(get_the_permalink()) . "' class='gbx__button gbx__button-" . esc_attr($this->layout->_id) . " " . esc_attr($this->layout->config['custom_class']) . "' " . $target . ">" . esc_html__($this->layout->config['button_text']) . "</a>";
                }
                break;
            case 'custom':

                if ($this->layout->config["prefix_type"] == 'icon' || $this->layout->config["suffix_type"] == 'icon') {
                    echo "<a href='" . esc_url($this->layout->config['field_value']) . "' class='gbx__button gbx__button-" . esc_attr($this->layout->_id) . " " . esc_attr($this->layout->config['custom_class']) . "' " . $target . ">";
                    $this->render_icon('prefix');
                    echo esc_html__($this->layout->config['button_text']);
                    $this->render_icon('suffix');
                    echo "</a>";
                } else {
                    echo "<a href='" . esc_url($this->layout->config['field_value']) . "' class='gbx__button gbx__button-" . esc_attr($this->layout->_id) . " " . esc_attr($this->layout->config['custom_class']) . "' " . $target . ">" . esc_html__($this->layout->config['button_text']) . "</a>";
                }
                break;
            case 'acfurl':
                if (is_array(get_field($this->layout->config['field_value']))) {
                    $url = get_field($this->layout->config['field_value'])['url'];
                } else {
                    $url = get_field($this->layout->config['field_value']);
                }

                if ($this->layout->config["prefix_type"] == 'icon' || $this->layout->config["suffix_type"] == 'icon') {
                    echo "<a href='" . esc_url($url) . "' class='gbx__button gbx__button-" . esc_attr($this->layout->_id) . " " . esc_attr($this->layout->config['custom_class']) . "' " . $target . ">";
                    $this->render_icon('prefix');
                    echo esc_html__($this->layout->config['button_text']);
                    $this->render_icon('suffix');
                    echo "</a>";
                } else {
                    echo "<a href='" . esc_url($url) . "' class='gbx__button gbx__button-" . esc_attr($this->layout->_id) . " " . esc_attr($this->layout->config['custom_class']) . "' " . $target . ">" . esc_html__($this->layout->config['button_text']) . "</a>";
                }
            case 'addtocart':
                // woocommerce check else break early
                if (!class_exists('WooCommerce')) {
                    break;
                }

                woocommerce_template_loop_add_to_cart();

                break;
            default:
                break;
        }
    }



    public function conditional_visibility()
    {
        $config = $this->layout->config;
        if (!isset($config['enable_visibility']) || $config['enable_visibility'] !== 'yes') {
            return false;
        }
        $data = json_decode($config['dynamic_field'] ?? '', true);
        $matches = 0;
        foreach ($data['gbx-group-a'] as $field) {
            $value = get_field($field['fieldkey']);
            if (empty($value)) {
                // echo "empty";
                break;
            }
            if (is_array($value)) {
                $value = implode(', ', $value);
            }

            if (is_numeric($value)) {
                $value = (float)$value; // Convert numeric strings to float
            }

            switch ($field['condition']) {
                case 'equal_to':
                    if ($value == $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'not_equal_to':
                    if ($value != $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'greater_than':

                    if ($value > $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'less_than':
                    if ($value < $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'greater_than_or_equal_to':
                    if ($value >= $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'less_than_or_equal_to':
                    if ($value <= $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'contains':
                    if (strpos($value, $field['fieldvalue']) !== false) {
                        $matches++;
                    }
                    break;
                case 'not_contains':
                    if (strpos($value, $field['fieldvalue']) === false) {
                        $matches++;
                    }
                    break;
                case 'starts_with':
                    if (strpos($value, $field['fieldvalue']) === 0) {
                        $matches++;
                    }
                    break;
                case 'ends_with':
                    if (substr($value, -strlen($field['fieldvalue'])) === $field['fieldvalue']) {
                        $matches++;
                    }
                    break;
                case 'is_empty':
                    if (empty($value)) {
                        $matches++;
                    }
                    break;
                case 'is_not_empty':
                    if (!empty($value)) {
                        $matches++;
                    }
                    break;
            }
        }
        $show_hide = $this->layout->config['show_hide'] ?? '';
        $one_or_all_match = $this->layout->config['one_or_all_match'] ?? '';
        if ($one_or_all_match == 'one' && $matches >= 1) {
            // At least one field matched
            if ($show_hide == 'show') {
                // Show the element
                return false;
            } else {
                // Hide the element
                // echo "hide";
                return true;
            }
        } else if ($one_or_all_match == 'all' && $matches == count($data['gbx-group-a'])) {
            // All fields matched
            if ($show_hide == 'show') {
                // Show the element
                return false;
            } else {
                // Hide the element
                // echo "hide2";
                return true;
            }
        } else {
            // No fields matched
            if ($show_hide == 'show') {
                // Hide the element
                return true;
            } else {
                // Show the element
                // echo "hide3";
                return false;
            }
        }
    }


    public function render()
    {
        $field_type  = $this->layout->field_type;
        switch ($field_type) {
            case 'text':
                $check = $this->conditional_visibility();
                if ($check) {
                    break;
                }
                $this->wrapper_start("gbx__title");
                $this->render_icon('prefix');
                $this->main_render_text();
                $this->render_icon('suffix');
                $this->wrapper_end();
                break;
            case 'image':
                $check = $this->conditional_visibility();
                if ($check) {
                    break;
                }
                $this->wrapper_start("gbx__image");
                $this->main_render_image();
                $this->wrapper_end();
                break;
            case 'button':
                $check = $this->conditional_visibility();
                if ($check) {
                    break;
                }
                $this->wrapper_start("gbx__button");
                $this->main_render_button();
                $this->wrapper_end();
                break;
            case 'meta':
                $check = $this->conditional_visibility();
                if ($check) {
                    break;
                }
                $this->wrapper_start("gbx__meta");
                $this->render_icon('prefix');
                $this->main_render_meta();
                $this->render_icon('suffix');
                $this->wrapper_end();
                break;
            case 'utilities':
                $check = $this->conditional_visibility();
                if ($check) {
                    break;
                }
                $this->wrapper_start("gbx__utilities");
                $this->main_render_utilities();
                $this->wrapper_end();
                break;

            default:
                break;
        }
    }
}
