<?php

namespace GRIDBUILDERX;

if (!defined('ABSPATH')) {
    exit;
}

class Layout
{

    public $field_type;
    public $config;
    public $_id;
    public $custom_class;
    public $custom_id;
    public $wrapper_tag;
    public $placeholder;

    public function __construct($field)
    {
        # primary data - These are data that which are loaded through setting fields directly
        $this->primary_data($field);

        # seocondary data - These are data that which are loaded based on the primary data
        $this->secondary_data($field);
    }

    protected function secondary_data($field)
    {

        $this->setter_config($field);
        $this->prefix_suffix_config($field, 'prefix');
        $this->prefix_suffix_config($field, 'suffix');
    }

    private function kind_setter($field, $key)
    {
        if (isset($field[$key])) {
            $kind = $field[$key];
        } else {
            $kind = $field['config']['kind'];
        }
        $this->config['kind'] = $kind;

        return $kind;
    }


    private function prefix_suffix_config($field, $main_key)
    {
        $key = $main_key . '_type';
        $this->configurator($field, $key);

        if (empty($this->config[$key])) {
            return;
        }

        if ($this->config[$key] == 'none') {
            return;
        }

        switch ($this->config[$key]) {
            case 'text':
                $this->configurator($field, $main_key . '_text');
                break;
            case 'icon':
                $this->configurator($field, $main_key . '_icon');
                break;
            case 'html':
                $this->configurator($field, $main_key . '_html');
                break;
            default:
                # code...
                break;
        }
    }

    private function configurator($field, $key)
    {
        $value = isset($field[$key]) ? $field[$key] : $this->check_if_set_in_config($field, $key);
        if ($value) {
            $this->config[$key] = $value;
        }
    }

    private function setter_config($field)
    {
        $this->config = array();
        $this->configurator($field, 'enable_hover_visibility');
        $this->configurator($field, 'enable_visibility');
        $this->configurator($field, 'show_hide');
        $this->configurator($field, 'one_or_all_match');
        $this->configurator($field, 'dynamic_field');

        $this->configurator($field, 'other_schema_property');
        $this->configurator($field, 'schema_property');
        $this->configurator($field, 'type_schema_property');
        $this->configurator($field, 'enable_image_lightbox');
        $this->configurator($field, 'is_rating');
        $this->configurator($field, 'rating_icons');


        switch ($this->field_type) {
            case 'text':
                $kind  = $this->kind_setter($field, 'text_type');
                $this->sub_setter_text($field, $kind);
                break;
            case 'image':
                $kind  = $this->kind_setter($field, 'image_type');
                $this->sub_setter_image($field, $kind);
                break;
            case 'button':
                $kind  = $this->kind_setter($field, 'button_type');

                $this->config['button_text'] = isset($field['button_text']) ? $field['button_text'] : ($field['config']['button_text'] ?? '');
                $this->config['open_in_new_tab'] = isset($field['open_in_new_tab']) ? $field['open_in_new_tab'] : ($field['config']['open_in_new_tab'] ?? '');
                $this->sub_setter_button($field, $kind);

                break;
            case 'meta':
                $kind  = $this->kind_setter($field, 'meta_type');
                $this->sub_setter_meta($field, $kind);
                break;
            case 'utilities':
                $kind  = $this->kind_setter($field, 'utility_type');
                $this->sub_setter_utilities($field, $kind);
                break;
            default:
                # code...
                break;
        }
    }

    //private function sub_setter_text
    private function sub_setter_text($field, $kind)
    {
        switch ($kind) {
                // cases title, plain_text, 'content',excerpt, 'custom', 'acf', 'woocommerce'
            case 'title':
                $this->configurator($field, 'enable_excerpt_trim');
                $this->configurator($field, 'excerpt_length');
                break;
            case 'plain_text':
                $this->configurator($field, 'plain_text');
                break;
            case 'content':
                $this->configurator($field, 'enable_excerpt_trim');
                $this->configurator($field, 'excerpt_length');
                break;
            case 'excerpt':
                $this->configurator($field, 'enable_excerpt_trim');
                $this->configurator($field, 'excerpt_length');
                break;
            case 'custom':
                $this->configurator($field, 'custom_field_key_text');
                $this->configurator($field, 'enable_excerpt_trim');
                $this->configurator($field, 'excerpt_length');
                break;
            case 'acf':
                $this->configurator($field, 'acf_field_key');
                $this->configurator($field, 'enable_excerpt_trim');
                $this->configurator($field, 'excerpt_length');
                $this->configurator($field, 'is_inside_group');
                $this->configurator($field, 'group_field_key');
                break;
            case 'woocommerce':
                $this->configurator($field, 'woocommerce_field_type');
                $this->configurator($field, 'enable_excerpt_trim');
                $this->configurator($field, 'excerpt_length');
                break;
            default:
                # code...
                break;
        }
    }

    // sub_setter_image function to handle featured , custom and acf image
    private function sub_setter_image($field, $kind)
    {
        switch ($kind) {
            case 'featured':
                $this->configurator($field, 'grid_image'); # placeholder
                $this->configurator($field, 'grid_image_size');
                $this->configurator($field, 'grid_image_custom_dimension');
                break;
            case 'custom':
                $this->configurator($field, 'grid_image'); # placeholder
                $this->configurator($field, 'grid_image_size');
                $this->configurator($field, 'grid_image_custom_dimension');
                $this->configurator($field, 'custom_field_key_image');
                break;
            case 'acf':
                $this->configurator($field, 'grid_image'); # placeholder
                $this->configurator($field, 'grid_image_size');
                $this->configurator($field, 'grid_image_custom_dimension');
                $this->configurator($field, 'acf_field_key_image');
                break;
            default:
                # code...
                break;
        }
    }

    private function sub_setter_button($field, $kind)
    {
        switch ($kind) {
            case 'acfurl':
                $this->config['field_value'] = isset($field['acf_field_key_button']) ? $field['acf_field_key_button'] : $field['config']['field_value'];
                break;
            case 'custom':
                $this->config['field_value'] = isset($field['custom_url']) ? $field['custom_url'] : $field['config']['field_value'];
                break;
            default:
                # code...
                break;
        }
    }

    private function sub_setter_utilities($field, $kind)
    {
        switch ($kind) {
            case 'icon':
                $this->config['field_value'] = isset($field['icon_custom_control']['value']) ? $field['icon_custom_control']['value'] : $field['config']['field_value'];
                $this->config['library'] = isset($field['icon_custom_control']['library']) ? $field['icon_custom_control']['library'] : $field['config']['library'];
                // covert the array to comma separated string
                // array to string
                break;
            case 'shortcode':
                $this->config['field_value'] = isset($field['shortcode']) ? $field['shortcode'] : $field['config']['field_value'];
                break;
            case 'html':
                $this->config['field_value'] = isset($field['html']) ? $field['html'] : $field['config']['field_value'];
                break;
            default:
                # code...
                break;
        }
    }


    private function sub_setter_meta($field, $kind)
    {
        switch ($kind) {
            case 'author':
                $this->config['field_value'] = isset($field['author_field']) ? $field['author_field'] : $field['config']['field_value'];

                break;
            case 'date':
                $this->config['field_value'] = isset($field['date_type']) ? $field['date_type'] : $field['config']['field_value'];
                // date format 
                $this->config['date_format'] = isset($field['date_format']) ? $field['date_format'] : $field['config']['date_format'];
                break;
            case 'categories':
                // taxonomies as field value
                $this->config['field_value'] = isset($field['taxonomies']) ? $field['taxonomies'] : $field['config']['field_value'];

                // no_of_taxonomies
                $this->config['no_of_taxonomies'] = isset($field['no_of_taxonomies']) ? $field['no_of_taxonomies'] : $field['config']['no_of_taxonomies'];

                // enable_link_terms
                $this->config['enable_link_terms'] = isset($field['enable_link_terms']) ? $field['enable_link_terms'] : $this->check_if_set_in_config($field, 'enable_link_terms');

                // open_term_links_in_new_tab , check if null as well
                $this->config['open_term_links_in_new_tab'] = isset($field['open_term_links_in_new_tab']) ? $field['open_term_links_in_new_tab'] : $this->check_if_set_in_config($field, 'open_term_links_in_new_tab');

                // separator
                $this->config['separator'] = isset($field['separator']) ? $field['separator'] : $field['config']['separator'] ?? '';

                // include_hierarchical
                $this->config['include_hierarchical'] = isset($field['include_hierarchical']) ? $field['include_hierarchical'] : $this->check_if_set_in_config($field, 'include_hierarchical');

                // include_terms
                $this->config['include_terms'] = isset($field['include_terms']) ? $field['include_terms'] : $this->check_if_set_in_config($field, 'include_terms');

                // exclude_terms
                $this->config['exclude_terms'] = isset($field['exclude_terms']) ? $field['exclude_terms'] : $this->check_if_set_in_config($field, 'exclude_terms');

                break;

            default:
                # code...
                break;
        }
    }

    private function check_if_set_in_config($field, $key)
    {
        if (isset($field['config'][$key])) {
            return $field['config'][$key];
        } else {
            return null;
        }
    }


    protected function primary_data($field)
    {
        $this->field_type = $field['field_type'];
        $this->_id = $field['_id'];
        $this->custom_class = $field['gbx_repeater_class'] ?? null;
        $this->custom_id = $field['gbx_repeater_id'] ?? null;
        $this->wrapper_tag = $field['wrapper_tag'] ?? null;
        $this->placeholder = $field['placeholder'] ?? null;
    }
}
