<?php

namespace GRIDBUILDERX;

if (!defined('ABSPATH')) {
    exit;
}

class Utils
{

    public static function get_list_of_all_acf_fields()
    {
        //check if acf is installed class check
        if (!class_exists('acf')) {
            return [];
        }

        $fields = [];
        // select 2 compatible list of all acf fields
        $field_groups = acf_get_field_groups();

        if ($field_groups) {
            foreach ($field_groups as $field_group) {
                //get field group title
                $field_group_title = $field_group['title'];

                $field_group_fields = acf_get_fields($field_group);
                if ($field_group_fields) {
                    foreach ($field_group_fields as $field) {
                        $fields[$field['name']] =  $field['label'] . ' ( ' . $field_group_title . ' )';
                    }
                }
            }
        }
        return $fields;
    }


    public static function get_list_of_all_taxonomies()
    {
        // Fetch public taxonomies
        $taxonomies = get_taxonomies(array(
            'public' => true,
        ), 'objects');



        //check if woocommerce is installed class check
        if (class_exists('WooCommerce')) {
            // Fetch WooCommerce product attributes
            $wc_attribute_taxonomies = wc_get_attribute_taxonomies();
            // Add the WooCommerce attributes to the taxonomies array
            if ($wc_attribute_taxonomies) {
                foreach ($wc_attribute_taxonomies as $wc_attribute) {
                    $taxonomy_name = wc_attribute_taxonomy_name($wc_attribute->attribute_name);
                    $taxonomies[$taxonomy_name] = get_taxonomy($taxonomy_name);
                }
            }
        }



        // Prepare the taxonomies list
        $taxonomies_list = array();
        foreach ($taxonomies as $taxonomy) {
            $taxonomies_list[$taxonomy->name] = $taxonomy->label;
        }

        return $taxonomies_list;
    }


    // function to get all templates in the elementor templates library
    public static function get_list_of_all_elementor_templates()
    {
        $templates = \Elementor\Plugin::$instance->templates_manager->get_source('local')->get_items();
        $templates_list = array();
        foreach ($templates as $template) {
            $templates_list[$template['template_id']] = $template['title'];
        }
        return $templates_list;
    }


    // function to get all public and post types
    public static function get_list_of_all_post_types()
    {
        $post_types = get_post_types(array(), 'objects');

        $post_types_list = array();
        foreach ($post_types as $post_type) {
            $post_types_list[$post_type->name] = $post_type->label;
        }
        return $post_types_list;
    }

    // function to get all authors
    public static function get_list_of_all_authors()
    {
        $authors = get_users(array());

        $authors_list = array();
        foreach ($authors as $author) {
            $authors_list[$author->ID] = $author->display_name;
        }
        return $authors_list;
    }

    public static function sanitize_images_html($image)
    {
        $allowed_html = array(
            'img' => array(
                'src' => array(),
                'alt' => array(),
                'title' => array(),
                'width' => array(),
                'height' => array(),
                'class' => array(),
                'id' => array(),
                'srcset' => array(),
                'sizes' => array(),
            ),
        );

        $sanitized_image = wp_kses($image, $allowed_html);

        return $sanitized_image;
    }
}
