<?php

namespace GRIDBUILDERX\Widgets;

use Elementor\Widget_Base;

if (!defined('ABSPATH')) {
    exit;
}

class Grid_Builder_Filtering extends Widget_Base
{

    public function get_name()
    {
        return 'grid-builder-x-filter';
    }
    public function get_title()
    {
        return esc_html__('Filter', 'gbx');
    }

    public function get_icon()
    {
        return 'eicon-filter';
    }

    public function get_categories()
    {
        return ['gbx_category'];
    }

    protected function register_controls()
    {
        include_once plugin_dir_path(__FILE__) . 'load/filters.php';
    }

    public function get_style_depends()
    {
        wp_enqueue_style('gbx-filtering', plugin_dir_url(dirname(__FILE__))  . 'assets/css/gen/filtering.min.css', GBX_VERSION, false);
        return ['gbx-filtering'];
    }

    public function get_script_depends()
    {
        wp_enqueue_script('gbx-noui', plugin_dir_url(dirname(__FILE__))  . 'assets/js/nouislider.js', ['jquery'], GBX_VERSION, false);
        wp_enqueue_script('gbx-filtering', plugin_dir_url(dirname(__FILE__))  . 'assets/js/gen/filtering.min.js', ['jquery'], GBX_VERSION, false);

        return ['gbx-noui', 'gbx-filtering'];
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $settings['gbx_grid_filter_id'];
        $filter_type = $settings['gbx_grid_filter_mode'];


        echo '<div class="gbx__filter__wrapper gbx__filter__wrapper-' . esc_attr($id) . '">';
        switch ($filter_type) {
            case 'clear':
                echo '<div class="gbx__filter__wrapper_element">';
                echo '<div class="gbx__filter__wrapper_ele gbx__filter__active-filters gbx__filter__active-filters-' . esc_attr($id) . '">';
                if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                    echo '<div class="gbx__filter__active-filters gbx__filter__active-filters-5f16c43"><button class="gbx__filter__remove-filter">Sample Item <span>×</span></button><button class="gbx__filter__remove-filter">Sample Item <span>×</span></button></div>';
                }
                echo "</div>"; // Add a div for active filters
                if ($settings['gbx_grid_filter_clear_button_text'] != '') :
                    echo '<button class="gbx__filter__clear-filters gbx__filter__clear-filters-' . esc_attr($id) . '">' . esc_html__($settings['gbx_grid_filter_clear_button_text'], 'gbx') . '</button>'; // Add a button to clear filters
                endif;
                echo "</div>";
                break;
            case 'search':
                echo '<div class="gbx__filter__wrapper_element">';
                echo '<div class="gbx__filter__search gbx__filter__search-' . esc_attr($id) . '">';
                echo '<div class="gbx__filter__search__icon_container">';
                echo '<div class="gbx__filter__search__icon">';
                \Elementor\Icons_Manager::render_icon($settings['gbx_grid_filter_meta_search_icon'], ['aria-hidden' => 'true']);
                echo '</div>';
                echo '<input data-grid-type="search" data-grid-connector="' . esc_attr($id) . '" type="text" class="gbx__filter__search__input gbx__filter__search__input-' . esc_attr($id) . '" placeholder="' . esc_html__($settings['gbx_grid_filter_placeholder_search'], 'gbx') . '">';
                echo '</div>';
                echo '</div>';
                echo "</div>";
                break;
            case 'orderby':
                $options_repeater_order = $settings['gbx_grid_filter_order_by_repeater'];
                echo '<div class="gbx__filter__wrapper_element">';
                echo '<select data-grid-type="orderby" data-grid-connector="' . esc_attr($id) . '" class="ui dropdown gbx__filter__dropdowns gbx__filter__orderby gbx__filter__orderby-' . esc_attr($id) . '">';
                echo '<option value="" selected disabled>' . esc_html__($settings['gbx_grid_filter_placeholder_orderby'], 'gbx') . '</option>'; // Add default empty option with a placeholder
                foreach ($options_repeater_order as $option) {
                    $data_attributes = 'data-orderby="' . esc_attr($option['gbx_orderby_filter']) . '" data-order="' . esc_attr($option['gbx_orderby_filter_order']) . '"';

                    if (!empty($option['gbx_orderby_filter_meta_key'])) {
                        $data_attributes .= ' data-meta-key="' . esc_attr($option['gbx_orderby_filter_meta_key']) . '"';
                    }

                    if (!empty($settings['gbx_grid_filter_meta_operator_type'])) {
                        $data_attributes .= ' data-meta-type="' . esc_attr($settings['gbx_grid_filter_meta_operator_type']) . '"';
                    }

                    echo '<option ' . $data_attributes . '>' . esc_html($option['gbx_orderby_filter_display']) . '</option>';
                }
                echo '</select>';
                echo "</div>";
                break;
            case 'taxonomy':
                $visual_element = $settings['gbx_grid_filter_visual_element_taxonomy']; // dropdown, checkbox, radio
                $taxonomy = $settings['gbx_grid_filter_taxonomy_list'];
                $place_holder = $settings['gbx_grid_filter_placeholder_taxonomy'];
                $terms_new = $settings['gbx_taxonomy_filter_list'];
                echo '<div class="gbx__filter__wrapper_element">';
                switch ($visual_element) {
                    case 'dropdown':
                        echo '<select ' . esc_attr($settings['gbx_grid_filter_multiple_select_taxonomy']) . ' data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" class="ui dropdown gbx__filter__dropdowns gbx__filter__taxonomy gbx__filter__taxonomy-' . esc_attr($id) . '">';
                        echo '<option value="" selected disabled>' . esc_html__($place_holder, 'gbx') . '</option>'; // Add default empty option with a placeholder
                        foreach ($terms_new as $term) {
                            echo '<option value="' . esc_attr($term['gbx_taxonomy_filter']) . '">';
                            echo esc_html($term['gbx_taxonomy_filter_title']);
                            echo '</option>';
                        }
                        echo '</select>';
                        break;
                    case 'checkbox':
                        $collapse_after = intval($settings['gbx_grid_filter_collapse_taxonomy']);

                        if ($collapse_after > 0) {
                            $first_terms = array_slice($terms_new, 0, $collapse_after);
                            $second_terms = array_slice($terms_new, $collapse_after);
                        } else {
                            $first_terms = $terms_new;
                            $second_terms = [];
                        }

                        echo '<div class="gbx__filter__taxonomy__checkbox-group gbx__filter__group__main">';
                        foreach ($first_terms as $term) {
                            echo '<div class="ui checkbox gbx__filter__taxonomy__checkbox gbx__filter__taxonomy__checkbox-' . esc_attr($id) . '">';
                            echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="checkbox" id="' . esc_attr($term['gbx_taxonomy_filter']) . '" value="' . esc_attr($term['gbx_taxonomy_filter_title']) . '">';
                            echo '<label for="' . esc_attr($term['gbx_taxonomy_filter']) . '">' . esc_html($term['gbx_taxonomy_filter_title']) . '</label>';
                            echo '</div>';
                        }
                        if (!empty($second_terms)) {
                            echo '<div class="gbx__filter__taxonomy__checkbox-group gbx__filter-group-collapse gbx__filter__group__secondary">';
                            foreach ($second_terms as $term) {
                                echo '<div class="ui checkbox gbx__filter__taxonomy__checkbox gbx__filter__element gbx__filter__taxonomy__checkbox-' . esc_attr($id) . '">';
                                echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="checkbox" id="' . esc_attr($term['gbx_taxonomy_filter']) . '" value="' . esc_attr($term['gbx_taxonomy_filter_title']) . '">';
                                echo '<label for="' . esc_attr($term['gbx_taxonomy_filter']) . '">' . esc_html($term['gbx_taxonomy_filter_title']) . '</label>';
                                echo '</div>';
                            }
                            echo '</div>';
                            echo '<button class="gbx-show-more">' . esc_html__('Show more', 'gbx') . '</button>';
                        }
                        echo '</div>';
                        break;
                    case 'radio':
                        $collapse_after = intval($settings['gbx_grid_filter_collapse_taxonomy']);
                        if ($collapse_after > 0) {
                            $first_terms = array_slice($terms_new, 0, $collapse_after);
                            $second_terms = array_slice($terms_new, $collapse_after);
                        } else {
                            $first_terms = $terms_new;
                            $second_terms = [];
                        }
                        echo '<div class="gbx__filter__taxonomy__radio-group gbx__filter__group__main">';
                        if (!empty($place_holder)) {
                            echo '<div class="ui radio checkbox gbx__filter__taxonomy__checkbox gbx__filter__taxonomy__checkbox-' . esc_attr($id) . ' gbx__filter__taxonomy__checkbox-all">';
                            echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="radio" name="' . esc_attr($taxonomy) . '" id="all_' . esc_attr($taxonomy) . '" value="" checked>';
                            echo '<label for="all_' . esc_attr($taxonomy) . '">' . esc_html__($place_holder, 'gbx') . '</label>';
                            echo '</div>';
                        }
                        foreach ($first_terms as $term) {
                            echo '<div class="ui radio checkbox gbx__filter__taxonomy__radio gbx__filter__taxonomy__radio-' . esc_attr($id) . '">';
                            echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="radio" name="' . esc_attr($taxonomy) . '" id="' . esc_attr($term['gbx_taxonomy_filter']) . '" value="' . esc_attr($term['gbx_taxonomy_filter']) . '">';
                            echo '<label for="' . esc_attr($term['gbx_taxonomy_filter']) . '">' . esc_html($term['gbx_taxonomy_filter_title']) . '</label>';
                            echo '</div>';
                        }

                        if (!empty($second_terms)) {
                            echo '<div class="gbx__filter__taxonomy__radio-group gbx__filter-group-collapse gbx__filter__group__secondary">';
                            foreach ($second_terms as $term) {
                                echo '<div class="ui radio checkbox gbx__filter__taxonomy__radio gbx__filter__element gbx__filter__taxonomy__radio-' . esc_attr($id) . '">';
                                echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="radio" name="' . esc_attr($taxonomy) . '" id="' . esc_attr($term['gbx_taxonomy_filter']) . '" value="' . esc_attr($term['gbx_taxonomy_filter']) . '">';
                                echo '<label for="' . esc_attr($term['gbx_taxonomy_filter']) . '">' . esc_html($term['gbx_taxonomy_filter_title']) . '</label>';
                                echo '</div>';
                            }
                            echo '</div>';
                            echo '<button class="gbx-show-more">' . esc_html__('Show more', 'gbx') . '</button>';
                        }
                        echo '</div>';
                        break;
                    case 'icons-checkbox':
                        echo '<div class="gbx-icon-filtering gbx__filter__icon-checkbox-group">';
                        foreach ($terms_new as $term) {
                            echo '<div class="elementor-repeater-item-' . esc_attr($term['_id']) . ' ui checkbox gbx__filter__taxonomy__icons-checkbox gbx__filter__taxonomy__icons-checkbox-' . esc_attr($id) . '">';
                            echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="checkbox" id="' . esc_attr($term['gbx_taxonomy_filter']) . '" value="' . esc_attr($term['gbx_taxonomy_filter_title']) . '" class="gbx-checked-border gbx-hidden-checkbox">';
                            echo '<label class="gbx-hidden-checkbox" for="' . esc_attr($term['gbx_taxonomy_filter']) . '">';
                            if (!empty($term['gbx_taxonomy_filter_icon'])) {
                                \Elementor\Icons_Manager::render_icon($term['gbx_taxonomy_filter_icon'], ['aria-hidden' => 'true']);
                            }
                            if ($settings['gbx_grid_filter_hide_icon_text_taxonomy'] == 'yes') {
                                //span for accessibility
                                echo '<span>' . esc_html($term['gbx_taxonomy_filter_title']) . '</span>';
                            } else {
                                //still echo the title for accessibility
                                echo '<span class="gbx-offseted-content">' . esc_html($term['gbx_taxonomy_filter_title']) . '</span>';
                            }
                            echo '</label>';
                            echo '</div>';
                        }
                        echo '</div>'; // Close the container div
                        break;
                    case 'icons-radio':
                        echo '<div class="gbx-icon-filtering gbx__filter__icon-checkbox-group">';
                        foreach ($terms_new as $term) {
                            echo '<div class="elementor-repeater-item-' . esc_attr($term['_id']) . ' ui radio checkbox gbx__filter__taxonomy__icons-radio gbx__filter__taxonomy__icons-radio-' . esc_attr($id) . '">';
                            echo '<input data-grid-type="taxonomy" data-grid-taxonomy="' . esc_attr($taxonomy) . '" data-grid-connector="' . esc_attr($id) . '" type="radio" name="' . esc_attr($taxonomy) . '-' . esc_attr($term['_id']) .  '" id="' . esc_attr($term['gbx_taxonomy_filter']) . '" value="' . esc_attr($term['gbx_taxonomy_filter']) . '" class="gbx-checked-border gbx-hidden-radio">';
                            echo '<label class="gbx-hidden-radio" for="' . esc_attr($term['gbx_taxonomy_filter']) . '">';
                            if (!empty($term['gbx_taxonomy_filter_icon'])) {
                                \Elementor\Icons_Manager::render_icon($term['gbx_taxonomy_filter_icon'], ['aria-hidden' => 'true']);
                            }
                            if ($settings['gbx_grid_filter_hide_icon_text_taxonomy'] == 'yes') {
                                //span for accessibility
                                echo '<span>' . esc_html($term['gbx_taxonomy_filter_title']) . '</span>';
                            } else {
                                //still echo the title for accessibility
                                echo '<span class="gbx-offseted-content">' . esc_html($term['gbx_taxonomy_filter_title']) . '</span>';
                            }
                            echo '</label>';
                            echo '</div>';
                        }
                        echo '</div>'; // Close the container div
                        break;
                }
                echo '</div>'; // Close the filter container
                break;
            case 'meta':
                $visual_element = $settings['gbx_grid_filter_visual_element_meta'];
                $operator = $settings['gbx_grid_filter_meta_operator'];
                $operator_type = $settings['gbx_grid_filter_meta_operator_type'];
                $options_repeater = $settings['gbx_grid_filter_meta_query'];
                echo '<div class="gbx__filter__wrapper_element">';
                switch ($visual_element) {
                    case 'slider':
                        $meta_key = $settings['gbx_grid_filter_meta_slider_key'];
                        $start = $settings['gbx_grid_filter_meta_slider_start'];
                        $min = $settings['gbx_grid_filter_meta_slider_value_min'];
                        $max = $settings['gbx_grid_filter_meta_slider_value_max'];
                        $step = $settings['gbx_grid_filter_meta_slider_step'];
                        echo '<div class="gbx__filter__slider">';
                        echo '<div data-grid-modified="no" data-meta-operatortype="' . esc_attr($operator_type) . '" data-grid-operator="' . esc_attr($operator) . '" data-grid-meta-key="' . esc_attr($meta_key) . '" data-step="' . esc_attr($step) . '" data-grid-connector="' . esc_attr($id) . '" data-start="' . esc_attr($start) . '" data-min="' . esc_attr($min) . '" data-max="' . esc_attr($max) . '" class="gbx__filter__slider__input gbx__filter__slider__input-' . esc_attr($id) . '"></div>';
                        echo '</div>';

                        break;

                    case 'dropdown':
                        echo '<select data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '"  data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" class="ui dropdown gbx__filter__dropdowns gbx__filter__meta gbx__filter__meta-' . esc_attr($id) . '">';
                        echo '<option value="" selected disabled>' . esc_html__($settings['gbx_grid_filter_placeholder_meta'], 'gbx') . '</option>'; // Add default empty option with a placeholder
                        foreach ($options_repeater as $option) {
                            echo '<option data-grid-value="' . esc_attr($option["gbx_meta_query_meta_value_filter"]) . '" value="' . esc_attr($option['gbx_meta_query_meta_key_filter']) . '">' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</option>';
                        }
                        echo '</select>';
                        break;
                    case 'checkbox':


                        $collapse_after = $settings['gbx_grid_filter_collapse_meta'];

                        if ($collapse_after > 0) {
                            $first_terms = array_slice($options_repeater, 0, $collapse_after);
                            $second_terms = array_slice($options_repeater, $collapse_after);
                        } else {
                            $first_terms = $options_repeater;
                            $second_terms = [];
                        }

                        echo '<div class="gbx__filter__meta__checkbox-group gbx__filter__group__main">';
                        foreach ($first_terms as $term) {
                            echo '<div class="ui checkbox gbx__filter__meta__checkbox gbx__filter__meta__checkbox-' . esc_attr($id) . '">';
                            echo '<input data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '" data-grid-value="' . esc_attr($term["gbx_meta_query_meta_value_filter"]) . '" data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="checkbox" id="' . esc_attr($term['_id']) . '" value="' . esc_attr($term['gbx_meta_query_meta_key_filter']) . '">';
                            echo '<label for="' . esc_attr($term['_id']) . '">' . esc_html__($term['gbx_meta_query_meta_key_filter_display'], 'gbx') . '</label>';
                            echo '</div>';
                        }

                        if (!empty($second_terms)) {
                            echo '<div class="gbx__filter__meta__checkbox-group gbx__filter-group-collapse gbx__filter__group__secondary">';
                            foreach ($second_terms as $term) {
                                echo '<div class="ui checkbox gbx__filter__meta__checkbox gbx__filter__element gbx__filter__meta__checkbox-' . esc_attr($id) . '">';
                                echo '<input data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '" data-grid-value="' . esc_attr($term["gbx_meta_query_meta_value_filter"]) . '" data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="checkbox" id="' . esc_attr($term['_id']) . '" value="' . esc_attr($term['gbx_meta_query_meta_key_filter']) . '">';
                                echo '<label for="' . esc_attr($term['_id']) . '">' . esc_html__($term['gbx_meta_query_meta_key_filter_display'], 'gbx') . '</label>';
                                echo '</div>';
                            }
                            echo '</div>';
                            echo '<button class="gbx-show-more">' . esc_html__('Show more', 'gbx') . '</button>';
                        }


                        echo '</div>';



                        break;
                    case 'radio':


                        $collapse_after = $settings['gbx_grid_filter_collapse_meta'];

                        if ($collapse_after > 0) {
                            $first_terms = array_slice($options_repeater, 0, $collapse_after);
                            $second_terms = array_slice($options_repeater, $collapse_after);
                        } else {
                            $first_terms = $options_repeater;
                            $second_terms = [];
                        }

                        echo '<div class="gbx__filter__meta__radio-group gbx__filter__group__main">';

                        if (!empty($settings['gbx_grid_filter_placeholder_meta'])) {
                            echo '<div class="ui radio checkbox gbx__filter__meta__radio gbx__filter__meta__radio-' . esc_attr($id) . '">
                                    <input data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="radio" name="gbx_meta_query_meta_key_filter" id="gbx_meta_query_meta_key_filter" value="" checked>
                                    <label for="gbx_meta_query_meta_key_filter">' . esc_html__($settings['gbx_grid_filter_placeholder_meta'], 'gbx') . '</label>
                                </div>';
                        }

                        foreach ($first_terms as $option) {
                            echo '<div class="ui radio checkbox gbx__filter__meta__radio gbx__filter__meta__radio-' . esc_attr($id) . '">';
                            echo '<input  data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '" data-grid-value="' . esc_attr($option["gbx_meta_query_meta_value_filter"]) . '" data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="radio" name="gbx_meta_query_meta_key_filter" id="' . esc_attr($option['_id']) . '" value="' . esc_attr($option['gbx_meta_query_meta_key_filter']) . '">';
                            echo '<label for="' . esc_attr($option['_id']) . '">' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</label>';
                            echo '</div>';
                        }

                        if (!empty($second_terms)) {
                            echo '<div class="gbx__filter__meta__radio-group gbx__filter-group-collapse gbx__filter__group__secondary">';
                            foreach ($second_terms as $option) {
                                echo '<div class="ui radio checkbox gbx__filter__meta__radio gbx__filter__element gbx__filter__meta__radio-' . esc_attr($id) . '">';
                                echo '<input  data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '" data-grid-value="' . esc_attr($option["gbx_meta_query_meta_value_filter"]) . '" data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="radio" name="gbx_meta_query_meta_key_filter" id="' . esc_attr($option['_id']) . '" value="' . esc_attr($option['gbx_meta_query_meta_key_filter']) . '">';
                                echo '<label for="' . esc_attr($option['_id']) . '">' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</label>';
                                echo '</div>';
                            }
                            echo '</div>';
                            echo '<button class="gbx-show-more">' . esc_html__('Show more', 'gbx') . '</button>';
                        }

                        echo '</div>';


                        break;
                    case 'icons-checkbox':
                        echo '<div class="gbx-icon-filtering gbx__filter__icon-checkbox-group">'; // Add a container div for the checkboxes
                        foreach ($options_repeater as $option) {
                            echo '<div class="elementor-repeater-item-' . esc_attr($option['_id']) . ' ui checkbox gbx__filter__meta__icon-checkbox gbx__filter__meta__icon-checkbox-' . esc_attr($id) . '">';
                            echo '<input data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '" data-grid-value="' . esc_attr($option["gbx_meta_query_meta_value_filter"]) . '" data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="checkbox" id="' . esc_attr($option['_id']) . '" value="' . esc_attr($option['gbx_meta_query_meta_key_filter']) . '"  class="gbx-checked-border">';
                            echo '<label for="' . esc_attr($option['_id']) . '">';
                            if ($option['gbx_meta_query_meta_icon_filter']) {
                                \Elementor\Icons_Manager::render_icon($option['gbx_meta_query_meta_icon_filter'], ['aria-hidden' => 'true']);
                            }
                            if ($settings['gbx_grid_filter_hide_icon_text_meta'] == 'yes') {
                                //span for accessibility
                                echo '<span>' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</span>';
                            } else {
                                //still echo the title for accessibility
                                echo '<span class="gbx-offseted-content">' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</span>';
                            }
                            echo '</label>';
                            echo '</div>';
                        }
                        echo '</div>'; // Close the container div
                        break;
                    case 'icons-radio':
                        echo '<div class="gbx-icon-filtering gbx__filter__icon-checkbox-group">'; // Add a container div for the radio buttons
                        foreach ($options_repeater as $option) {

                            echo '<div class="elementor-repeater-item-' . esc_attr($option['_id']) . ' ui radio checkbox gbx__filter__meta__icon-radio gbx__filter__meta__icon-radio-' . esc_attr($id) . '">';
                            echo '<input data-meta-operatortype="' . esc_attr($operator_type) . '" data-meta-operator="' . esc_attr($operator) . '" data-grid-value="' . esc_attr($option["gbx_meta_query_meta_value_filter"]) . '" data-grid-type="meta" data-grid-connector="' . esc_attr($id) . '" type="radio" name="gbx_meta_query_meta_key_filter-' . esc_attr($option['gbx_meta_query_meta_key_filter']) . '" id="' . esc_attr($option['_id']) . '" value="' . esc_attr($option['gbx_meta_query_meta_key_filter']) . '"   class="gbx-checked-border">';
                            echo '<label for="' . esc_attr($option['_id']) . '">';
                            if ($option['gbx_meta_query_meta_icon_filter']) {
                                \Elementor\Icons_Manager::render_icon($option['gbx_meta_query_meta_icon_filter'], ['aria-hidden' => 'true']);
                            }
                            if ($settings['gbx_grid_filter_hide_icon_text_meta'] == 'yes') {
                                //span for accessibility
                                echo '<span>' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</span>';
                            } else {
                                //still echo the title for accessibility
                                echo '<span class="gbx-offseted-content">' . esc_html($option['gbx_meta_query_meta_key_filter_display']) . '</span>';
                            }
                            echo '</label>';
                            echo '</div>';
                        }
                        echo '</div>'; // Close the container div
                        break;
                }
                echo '</div>';
                break;
        }
        echo '</div>';
    }
}
