<?php

namespace GRIDBUILDERX\Widgets;

use Elementor\Widget_Base;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class Grid_Builder_X
 * @package GRIDBUILDERX\Widgets
 */

class Grid_Builder_X extends Widget_Base
{
    // load the dependencies
    public function __construct($data = [], $args = null)
    {
        parent::__construct($data, $args);
        // load the dependencies
        $this->load_dependencies();
    }

    // load the dependencies
    private function load_dependencies()
    {
        // load the args builder
        require_once plugin_dir_path(dirname(__FILE__)) . 'class/args-builder.php';

        // load the query builder
        require_once plugin_dir_path(dirname(__FILE__)) . 'class/query-builder.php';
    }

    /**
     * Get widget name.
     * Retrieve Grid Builder X widget name.
     * @since 1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'grid-builder-x';
    }


    public function get_style_depends()
    {
        wp_enqueue_style('gbx', plugin_dir_url(dirname(__FILE__))  . 'assets/css/gen/gbx.min.css', GBX_VERSION, false);
        return ['gbx'];
    }

    /**
     * Get widget title.
     * Retrieve Grid Builder X widget title.
     * @since 1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Grid Builder X', 'gbx');
    }

    /**
     * Get widget icon.
     * Retrieve Grid Builder X widget icon.
     * @since 1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-gallery-grid';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the Grid Builder X widget belongs to.
     * @since 1.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['gbx_category'];
    }

    /**
     * Register Grid Builder X widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls()
    {
        # register controls
        include_once plugin_dir_path(__FILE__) . 'load/grid-configure.php';
        include_once plugin_dir_path(__FILE__) . 'load/grid-designer.php';
        include_once plugin_dir_path(__FILE__) . 'load/grids-designer.php';
        include_once plugin_dir_path(__FILE__) . 'load/arg-builder.php';
        include_once plugin_dir_path(__FILE__) . 'load/animation-composer.php';
        include_once plugin_dir_path(__FILE__) . 'load/schema.php';
    }

    /**
     * Render Grid Builder X widget output on the frontend.
     * Written in PHP and used to generate the final HTML
     * @since 1.0.0
     * @access protected
     */

    private function load_scripts($id, $layout, $args)
    {
        wp_enqueue_script('gbx', plugin_dir_url(dirname(__FILE__)) . 'assets/js/gen/gbx.min.js', array('jquery'), GBX_VERSION, true);
        wp_localize_script(
            'gbx',
            'gbx_ajax_object' . $this->get_id(),
            array(
                'ajax_url' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('gbx-nonce'),
                'grid_id' => $id,
                'layout' => json_encode($layout),
                'args' => json_encode($args)
            ),
        );
    }


    private function layout_handler($layout_settings)
    {
        $layout = array();
        $layout_builder = new \GRIDBUILDERX\Layout_Builder($layout_settings);
        $layout = $layout_builder->get_layout();
        return $layout;
    }

    private function grids_background_handler($settings, $layout)
    {
        if (isset($settings['gbx_grid_background_type']) && $settings['gbx_grid_background_type'] == 'featuredimage') {
            $layout['background'] = array(
                'type' => 'featured_image',
                'paceholder' => $settings['gbx_grid_background_placeholder'],
                'size' => $settings['gbx_grid_background_placeholder_size'],
            );
            if (isset($settings['gbx_grid_background_placeholder_custom_dimension'])) {
                $layout['background']['custom_size'] = $settings['gbx_grid_background_placeholder_custom_dimension'];
            }
        } else if (isset($settings['gbx_grid_background_type']) && $settings['gbx_grid_background_type'] == 'acf') {
            $layout['background'] = array(
                'type' => 'acf',
                'paceholder' => $settings['gbx_grid_background_placeholder'],
                'field' => $settings['gbx_grid_background_custom_field'],
                'size' => $settings['gbx_grid_background_placeholder_size']
            );
            if (isset($settings['gbx_grid_background_placeholder_custom_dimension'])) {
                $layout['background']['custom_size'] = $settings['gbx_grid_background_placeholder_custom_dimension'];
            }
        }
        return $layout;
    }

    private function schema_handler($settings)
    {
        $schema = array();
        if ($settings['enable_schema'] == 'yes') {
            $schema['enable'] = true;
            $schema['type'] = $settings['schema_type'];
            //organization
            $schema['organization_name'] = $settings['organization_name'];
            $schema['organization_logo'] = $settings['organization_logo']['url'];
            $schema['organization_url'] = $settings['organization_url']['url'];
        }
        return $schema;
    }

    private function schemea_data_generator($layout, $title, $value, $data)
    {
        if (isset($layout['schema']['enable']) && $layout['schema']['enable'] == 1) {
            if (isset($layout[$title][$value])) {
                return "data-" . $data . "=" . $layout[$title][$value];
            }
        }
    }




    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $layout_settings = $settings['gbx_grid_designer'];
        $no_more_posts = $settings['gbx_grid_no_more_posts_message'];
        $layout = $this->layout_handler($layout_settings);
        $id = $this->get_id();

        $args = new \GRIDBUILDERX\Arg_Builder($settings);
        $args = $args->get_args();

        $query = new \GRIDBUILDERX\Query_Builder($args, $id);
        $max_pages = $query->maximum_posts;
        $this->add_render_attribute(
            '_gbx_maxpages',
            [
                'data-maxpages' => $max_pages,
            ]
        );

        $layout =  $this->grids_background_handler($settings, $layout);

        $clickable_grid = $settings['gbx_grid_clickable'];
        $clickable_grid = $clickable_grid == 'yes' ? true : false;

        if ($clickable_grid) {
            $layout['clickable'] = array(
                'type' => $settings['gbx_grid_link_type'],
                'target' => $settings['gbx_grid_link_target'],
            );

            if ($settings['gbx_grid_link_type'] == 'custom') {
                if (isset($settings['gbx_grid_link_custom'])) {
                    $layout['clickable']['custom'] = $settings['gbx_grid_link_custom'];
                }
            }

            if ($settings['gbx_grid_link_type'] == 'acf') {
                if (isset($settings['gbx_grid_acf_link'])) {
                    $layout['clickable']['acffield'] = $settings['gbx_grid_acf_link'];
                }
            }
        }

        $layout['idofgrid'] = $id;
        $this->load_scripts($id, $layout, $args);

        // append schema to layout -  $this->schema_handler($settings);
        $layout['schema'] = $this->schema_handler($settings);

        echo '<div ' . $this->get_render_attribute_string('_gbx_maxpages') . ' class="gbx gbx-grids gbx-' . esc_attr($id) . '" data-nomoreposts="' . esc_html__($no_more_posts) . '"   data-connector=' . esc_attr($id) . '  ' . $this->schemea_data_generator($layout, 'schema', 'type', "schema") . ' ' . $this->schemea_data_generator($layout, 'schema', 'organization_name', "name") . ' ' . $this->schemea_data_generator($layout, 'schema', 'organization_logo', "logo") . ' ' . $this->schemea_data_generator($layout, 'schema', 'organization_url', "url") . '>';
        $query->the_posts($layout);
        echo '</div>';

        // if in elementor editor mode the classanimatiion is removed
        if (\Elementor\Plugin::instance()->editor->is_edit_mode()) {
            if (isset($settings['display_widget_id']) && $settings['display_widget_id'] == 'yes') {
?><a href="#" onclick="copyWidgetId('<?php echo esc_html($this->get_id()); ?>')"><?php esc_html_e("Copy Widget ID"); ?></a>
<?php
            }
        }
        // pagination type

    }
}
