<?php

namespace GRIDBUILDERX\Widgets;

use Elementor\Widget_Base;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class Grid_Builder_X
 * @package GRIDBUILDERX\Widgets
 */

class Grid_Builder_Pagination extends Widget_Base
{

    public function get_name()
    {
        return 'grid-builder-x-pagination';
    }
    public function get_title()
    {
        return esc_html__('Pagination', 'gbx');
    }

    public function get_icon()
    {
        return 'eicon-loading';
    }

    public function get_categories()
    {
        return ['gbx_category'];
    }

    protected function register_controls()
    {
        include_once plugin_dir_path(__FILE__) . 'load/pagination.php';
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $id = $settings['gbx_grid_id'];

        $pagination_type = $settings['gbx_pagination_type'];

        if ($pagination_type != 'none') {
            echo '<div class="gbx__pagination__wrapper gbx__pagination__wrapper-' . esc_attr($id) . '">';
            switch ($pagination_type) {
                case 'loadmore':
                    echo '<div data-paginationtype="' . $pagination_type . '" class="gbx_pagination-' . $id . '  gbx-button-loadmore gbx-button-loadmore-' . esc_attr($id) . '">';
                    echo '<button data-load="' . esc_html($settings['gbx_pagination_load_more_text']) . '"  data-loading="' . esc_html($settings['gbx_pagination_load_more_loading_text']) . '" class="gbx__loadmore__btn-' . $id . '">' . esc_html($settings['gbx_pagination_load_more_text']) . '</button>';
                    echo '</div>';
                    break;
                case 'infinite':
                    echo $this->displaySpinner($settings['gbx_pagination_loading_spinner_type']); // TODO: escape
                    //editor mode
                    if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                        echo '<style>.gbx-scod-loader { display: inherit !important; } </style>';
                    }
                    echo '<div data-paginationtype="' . $pagination_type . '" class="gbx_pagination-' . $id . '  gbx__loadmore-' . $id . '"></div>';
                    break;
                case 'pagination':
?>
                    <div data-paginationtype="<?php echo esc_attr($pagination_type); ?>" class="gbx__pagination_container gbx__pagination__container-<?php echo esc_attr($id); ?> gbx_pagination-<?php echo esc_attr($id); ?>">
                        <div class="gbx__pagination__numbers gbx__pagination__numbers-<?php echo esc_attr($id); ?>">
                            <div class="gbx__pagination_numbered gbx__pagination_numbered-<?php echo esc_attr($id); ?> ">
                                <div class="gbx__pagination__item gbx__page__prev gbx__page__prev-<?php echo esc_attr($id); ?> gbx__pagination__item-<?php echo esc_attr($id); ?>" id="gbx-previous-page-<?php echo esc_attr($id); ?>"><span class="gbx-page-link" href="javascript:void(0)"><?php \Elementor\Icons_Manager::render_icon($settings['gbx_pagination_numbered_prev_icon'], ['aria-hidden' => 'true']); ?></span><?php echo esc_html_e($settings['gbx_pagination_numbered_prev_text']) ?></div>
                                <?php
                                //if elementor editor mode
                                if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                                ?>
                                    <div class="gbx__pagination__item gbx__pagination__item-d28c99a gbx-current-page gbx-current-page-d28c99a gbx-active gbx-active-d28c99a" data-page="1">
                                        <div class="gbx-page-link gbx-page-link-d28c99a">1</div>
                                    </div>
                                    <div class="gbx__pagination__item gbx__pagination__item-d28c99a gbx-current-page gbx-current-page-d28c99a" data-page="2">
                                        <div class="gbx-page-link gbx-page-link-d28c99a">2</div>
                                    </div>
                                    <div class="gbx__pagination__item gbx__pagination__item-d28c99a gbx-current-page gbx-current-page-d28c99a" data-page="3">
                                        <div class="gbx-page-link gbx-page-link-d28c99a">3</div>
                                    </div>
                                    <div class="gbx__pagination__item gbx__pagination__item-d28c99a gbx-current-page gbx-current-page-d28c99a" data-page="4">
                                        <div class="gbx-page-link gbx-page-link-d28c99a">4</div>
                                    </div>
                                <?php
                                }
                                ?>

                                <div class="gbx__pagination__item gbx__page__next gbx__page__next-<?php echo esc_attr($id); ?> gbx__pagination__item-<?php echo esc_attr($id); ?>" id="gbx-next-page-<?php echo esc_attr($id); ?>"><?php echo esc_html_e($settings['gbx_pagination_numbered_next_text']) ?><span class="gbx-page-link" href="javascript:void(0)"><?php \Elementor\Icons_Manager::render_icon($settings['gbx_pagination_numbered_next_icon'], ['aria-hidden' => 'true']); ?></span></div>
                            </div>
                        </div>
                    </div>
<?php
                    break;
                default:
                    break;
            }
            echo '</div>';
        }
    }

    private function displaySpinner($spinner_type)
    {
        $spinner_html = '';
        switch ($spinner_type) {
            case 'roller':
                $spinner_html = '<div class="gbx-scod gbx-roller">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
            case 'ripple':
                $spinner_html = '<div class="gbx-scod gbx-ripple">
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
            case 'dual-ring':
                $spinner_html = '<div class="gbx-scod gbx-dual-ring"></div>';
                break;
            case 'facebook':
                $spinner_html = '<div class="gbx-scod gbx-facebook">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
            case 'ring':
                $spinner_html = '<div class="gbx-scod gbx-ring">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
            case 'ellipsis':
                $spinner_html = '<div class="gbx-scod gbx-ellipsis">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
            case 'grid':
                $spinner_html = '<div class="gbx-scod gbx-grid">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
            case 'spinner':
            default:
                $spinner_html = '<div class="gbx-scod gbx-spinner">
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                    <div></div>
                                </div>';
                break;
        }

        return '<div class="gbx-scod-loader"><div class="gbx-spinner-main"><div>' . $spinner_html . '</div></div></div>';
    }
}
