<?php

// if accessed directly than exit
if (!defined('ABSPATH')) {
    exit;
}

$this->start_controls_section(
    'gbx_animation',
    [
        'label' => esc_html__('Animation Composer', 'gbx'),
    ]
);


// Transform control for .grid__item__animated
$this->add_control(
    'gbx_animation_transform',
    [
        'label' => esc_html__('Initial Transform', 'gbx'),
        'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
        'return_value' => 'yes',
    ]
);

$this->start_popover();

$this->add_control(
    'gbx_animation_translateX',
    [
        'label' => esc_html__('Translate X', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => -500,
                'max' => 500,
                'step' => 1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated' => 'transform: translate({{SIZE}}px, {{gbx_animation_translateY.SIZE || 0}}px) scale({{gbx_animation_scale.SIZE || 1}});',
            // padding top to compensate for the height of the element

        ],
    ]
);

$this->add_control(
    'gbx_animation_translateY',
    [
        'label' => esc_html__('Translate Y', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => -500,
                'max' => 500,
                'step' => 1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated' => 'transform: translate({{gbx_animation_translateX.SIZE || 0}}px, {{SIZE}}px) scale({{gbx_animation_scale.SIZE || 1}});',
        ],
    ]
);

$this->add_control(
    'gbx_animation_scale',
    [
        'label' => esc_html__('Scale', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated' => 'transform: translate({{gbx_animation_translateX.SIZE || 0}}px, {{gbx_animation_translateY.SIZE || 0}}px) scale({{SIZE}});',
        ],
    ]
);

$this->add_control(
    'gbx_animation_opacity',
    [
        'label' => esc_html__('Opacity', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'default' => [
            'size' => 0,
        ],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated' => 'opacity: {{SIZE}};',
        ],
    ]
);


$this->end_popover();

// Transform control for .grid__item__animated.visible
$this->add_control(
    'gbx_animation_transform_visible',
    [
        'label' => esc_html__('Visible Transform', 'gbx'),
        'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
        'return_value' => 'yes',
    ]
);

$this->start_popover();

$this->add_control(
    'gbx_animation_translateX_visible',
    [
        'label' => esc_html__('Translate X Visible', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => -500,
                'max' => 500,
                'step' => 1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated.visible' => 'transform: translate({{SIZE}}px, {{gbx_animation_translateY_visible.SIZE || 0}}px) scale({{gbx_animation_scale_visible.SIZE || 1}});',
        ],
    ]
);

$this->add_control(
    'gbx_animation_translateY_visible',
    [
        'label' => esc_html__('Translate Y Visible', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => -500,
                'max' => 500,
                'step' => 1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated.visible' => 'transform: translate({{gbx_animation_translateX_visible.SIZE || 0}}px, {{SIZE}}px) scale({{gbx_animation_scale_visible.SIZE || 1}});',
        ],
    ]
);

$this->add_control(
    'gbx_animation_scale_visible',
    [
        'label' => esc_html__('Scale Visible', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated.visible' => 'transform: translate({{gbx_animation_translateX_visible.SIZE || 0}}px, {{gbx_animation_translateY_visible.SIZE || 0}}px) scale({{SIZE}});',
        ],
    ]
);

$this->add_control(
    'gbx_animation_opacity_visible',
    [
        'label' => esc_html__('Opacity Visible', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'default' => [
            'size' => 1,
        ],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} .grid__item__animated.visible' => 'opacity: {{SIZE}};',
        ],
    ]
);

$this->end_popover();


// switcher to refresh the page
$this->add_control(
    'gbx_animation_refresh',
    [
        'label' => esc_html__('Toggle on and off to test the animation', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('On', 'gbx'),
        'label_off' => esc_html__('Off', 'gbx'),
        'return_value' => 'yes',
        'default' => 'no',
    ]
);



$this->end_controls_section();
