<?php

// if accessed directly than exit
if (!defined('ABSPATH')) {
    exit;
}

$this->start_controls_section(
    'gbx_arg_builder',
    [
        'label' => esc_html__('Grid Query Builder', 'gbx'),
    ]
);

//post per page
$this->add_control(
    'gbx_posts_per_page',
    [
        'label' => esc_html__('Posts Per Page', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'default' => 8,
    ]
);

// select post type multiple
$this->add_control(
    'gbx_post_type',
    [
        'label' => esc_html__('Custom Post Type', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'options' => GRIDBUILDERX\Utils::get_list_of_all_post_types(),
        'multiple' => true,
        'default' => 'post',
    ]
);

//order by
$this->add_control(
    'gbx_order_by',
    [
        'label' => esc_html__('Order By', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'date' => esc_html__('Date', 'gbx'),
            'title' => esc_html__('Title', 'gbx'),
            'rand' => esc_html__('Random', 'gbx'),
            'menu_order' => esc_html__('Menu Order', 'gbx'),
            'ID' => esc_html__('ID', 'gbx'),
            'author' => esc_html__('Author', 'gbx'),
            'comment_count' => esc_html__('Comment Count', 'gbx'),
            'modified' => esc_html__('Modified', 'gbx'),
            'parent' => esc_html__('Parent', 'gbx'),
            'relevance' => esc_html__('Relevance', 'gbx'),
            'slug' => esc_html__('Slug', 'gbx'),
            'meta_value' => esc_html__('Meta Value', 'gbx'),
            'meta_value_num' => esc_html__('Meta Value Num', 'gbx'),
            'post__in' => esc_html__('Post In', 'gbx'),
        ],
        'default' => 'date',
    ]
);


// meta key
$this->add_control(
    'gbx_meta_key',
    [
        'label' => esc_html__('Meta Key', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => '',
        'condition' => [
            'gbx_order_by' => ['meta_value', 'meta_value_num'],
        ],
    ]
);

// // meta value
// $this->add_control(
//     'gbx_meta_value',
//     [
//         'label' => esc_html__('Meta Value', 'gbx'),
//         'type' => \Elementor\Controls_Manager::TEXT,
//         'default' => '',
//         'condition' => [
//             'gbx_order_by' => 'meta_value',
//         ],
//     ]
// );

// meta value num
// $this->add_control(
//     'gbx_meta_value_num',
//     [
//         'label' => esc_html__('Meta Value Num', 'gbx'),
//         'type' => \Elementor\Controls_Manager::TEXT,
//         'default' => '',
//         'condition' => [
//             'gbx_order_by' => 'meta_value_num',
//         ],
//     ]
// );

//select author
$this->add_control(
    'gbx_author',
    [
        'label' => esc_html__('Author', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'options' => GRIDBUILDERX\Utils::get_list_of_all_authors(),
        'multiple' => true,
        'default' => '',
    ]
);

// mete compare type
$this->add_control(
    'gbx_meta_type',
    [
        'label' => esc_html__('Meta Type', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'CHAR' => esc_html__('Char', 'gbx'),
            'NUMERIC' => esc_html__('Numeric', 'gbx'),
            'BINARY' => esc_html__('Binary', 'gbx'),
            'DATE' => esc_html__('Date', 'gbx'),
            'DATETIME' => esc_html__('Datetime', 'gbx'),
            'DECIMAL' => esc_html__('Decimal', 'gbx'),
            'SIGNED' => esc_html__('Signed', 'gbx'),
            'TIME' => esc_html__('Time', 'gbx'),
            'UNSIGNED' => esc_html__('Unsigned', 'gbx'),
        ],
        'default' => 'CHAR',
        'condition' => [
            'gbx_order_by' => ['meta_value', 'meta_value_num'],
        ],
    ]
);

// meta compare
$this->add_control(
    'gbx_meta_compare',
    [
        'label' => esc_html__('Meta Compare', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            '=' => esc_html__('Equal', 'gbx'),
            '!=' => esc_html__('Not Equal', 'gbx'),
            '>' => esc_html__('Greater Than', 'gbx'),
            '>=' => esc_html__('Greater Than Equal', 'gbx'),
            '<' => esc_html__('Less Than', 'gbx'),
            '<=' => esc_html__('Less Than Equal', 'gbx'),
            'LIKE' => esc_html__('Like', 'gbx'),
            'NOT LIKE' => esc_html__('Not Like', 'gbx'),
            'IN' => esc_html__('In', 'gbx'),
            'NOT IN' => esc_html__('Not In', 'gbx'),
            'BETWEEN' => esc_html__('Between', 'gbx'),
            'NOT BETWEEN' => esc_html__('Not Between', 'gbx'),
            'EXISTS' => esc_html__('Exists', 'gbx'),
            'NOT EXISTS' => esc_html__('Not Exists', 'gbx'),
        ],
        'default' => '=',
        'condition' => [
            'gbx_order_by' => ['meta_value', 'meta_value_num'],
        ],
    ]
);

//post in
$this->add_control(
    'gbx_post_in',
    [
        'label' => esc_html__('Post In', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'description' => esc_html__('Enter post ids separated by comma', 'gbx'),
        'condition' => [
            'gbx_order_by' => 'post__in',
        ],
    ]
);


// acending or decending
$this->add_control(
    'gbx_order',
    [
        'label' => esc_html__('Order', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'ASC' => esc_html__('Ascending', 'gbx'),
            'DESC' => esc_html__('Descending', 'gbx'),
        ],
        'default' => 'DESC',
    ]
);

//post status
$this->add_control(
    'gbx_post_status',
    [
        'label' => esc_html__('Post Status', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'options' => [
            'publish' => esc_html__('Publish', 'gbx'),
            'pending' => esc_html__('Pending', 'gbx'),
            'draft' => esc_html__('Draft', 'gbx'),
            'auto-draft' => esc_html__('Auto Draft', 'gbx'),
            'future' => esc_html__('Future', 'gbx'),
            'private' => esc_html__('Private', 'gbx'),
            'inherit' => esc_html__('Inherit', 'gbx'),
            'trash' => esc_html__('Trash', 'gbx'),
            'any' => esc_html__('Any', 'gbx'),
        ],
        'default' => 'publish',
        'multiple' => true,
    ]
);

// password protected
$this->add_control(
    'gbx_password_protected',
    [
        'label' => esc_html__('Password Protected', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'yes' => esc_html__('Yes', 'gbx'),
            'no' => esc_html__('No', 'gbx'),
        ],
        'default' => 'no',
    ]
);

//post offset
$this->add_control(
    'gbx_offset',
    [
        'label' => esc_html__('Offset', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'default' => 0,
    ]
);

// exclude posts
$this->add_control(
    'gbx_exclude_posts',
    [
        'label' => esc_html__('Exclude Posts', 'gbx'),
        'type' => 'gbx-search-posts',
        'description' => esc_html__('Enter exact title of post name', 'gbx'),
    ]
);

// include posts
$this->add_control(
    'gbx_include_posts',
    [
        'label' => esc_html__('Include Posts', 'gbx'),
        'type' => 'gbx-search-posts',
        'description' => esc_html__('Enter exact title of post name', 'gbx'),
    ]
);


// search posts
$this->add_control(
    'gbx_search_posts',
    [
        'label' => esc_html__('Search Posts', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'description' => esc_html__('Enter search keyword', 'gbx'),
    ]
);


// repeater tax query builder
$repeater_tax_query = new \Elementor\Repeater();


// relation or taxonomy choose 
$repeater_tax_query->add_control(
    'gbx_tax_query_relation_or_taxonomy',
    [
        'label' => esc_html__('Relation or Taxonomy', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'relation' => esc_html__('Relation', 'gbx'),
            'taxonomy' => esc_html__('Taxonomy', 'gbx'),
        ],
        'default' => 'taxonomy',
    ]
);

// nesting level
$repeater_tax_query->add_control(
    'gbx_tax_query_nesting_level',
    [
        'label' => esc_html__('Nesting Level', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'default' => 0,
        'condition' => [
            'gbx_tax_query_relation_or_taxonomy' => 'relation',
        ],
    ]
);


// relation
$repeater_tax_query->add_control(
    'gbx_tax_query_relation',
    [
        'label' => esc_html__('Relation', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'AND' => esc_html__('AND', 'gbx'),
            'OR' => esc_html__('OR', 'gbx'),
        ],
        'default' => 'AND',
        'condition' => [
            'gbx_tax_query_relation_or_taxonomy' => 'relation',
        ],
    ]
);

// type args_builder
$repeater_tax_query->add_control(
    'gbx_tax_query_taxonomy',
    [
        'type' => 'args_builder',
        'taxonomy' => \GRIDBUILDERX\Utils::get_list_of_all_taxonomies(),
        'condition' => [
            'gbx_tax_query_relation_or_taxonomy' => 'taxonomy',
        ],
    ]
);

//operator
$repeater_tax_query->add_control(
    'gbx_tax_query_operator',
    [
        'label' => esc_html__('Operator', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'IN' => esc_html__('IN', 'gbx'),
            'NOT IN' => esc_html__('NOT IN', 'gbx'),
            'AND' => esc_html__('AND', 'gbx'),
            'EXISTS' => esc_html__('EXISTS', 'gbx'),
            'NOT EXISTS' => esc_html__('NOT EXISTS', 'gbx'),
        ],
        'default' => 'IN',
        'condition' => [
            'gbx_tax_query_relation_or_taxonomy' => 'taxonomy',
        ],
    ]
);


// repeater
$this->add_control(
    'gbx_repeater_tax_query_builder',
    [
        'label' => esc_html__('Tax Query | add tax query, Categories, Tags, Custom Taxonomies', 'gbx'),
        'fields' => $repeater_tax_query->get_controls(),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'description' => esc_html__('Add tax query, Categories, Tags, Custom Taxonomies', 'gbx'),
        'title_field' => '{{{ gbx_tax_query_relation_or_taxonomy }}}',
        'prevent_empty' => false,
    ]
);


// meta query builder
$repeater_meta_query = new \Elementor\Repeater();

// relation or meta key choose
$repeater_meta_query->add_control(
    'gbx_meta_query_relation_or_meta_key',
    [
        'label' => esc_html__('Relation or Meta Key', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'relation' => esc_html__('Relation', 'gbx'),
            'meta_key' => esc_html__('Meta Key', 'gbx'),
        ],
        'default' => 'meta_key',
    ]
);


// relation
$repeater_meta_query->add_control(
    'gbx_meta_query_relation',
    [
        'label' => esc_html__('Relation', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'AND' => esc_html__('AND', 'gbx'),
            'OR' => esc_html__('OR', 'gbx'),
        ],
        'default' => 'AND',
        'condition' => [
            'gbx_meta_query_relation_or_meta_key' => 'relation',
        ],
    ]
);

//meta key
$repeater_meta_query->add_control(
    'gbx_meta_query_meta_key',
    [
        'label' => esc_html__('Meta Key', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'condition' => [
            'gbx_meta_query_relation_or_meta_key' => 'meta_key',
        ],
    ]
);

//meta value
$repeater_meta_query->add_control(
    'gbx_meta_query_meta_value',
    [
        'label' => esc_html__('Meta Value', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'condition' => [
            'gbx_meta_query_relation_or_meta_key' => 'meta_key',
        ],
    ]
);

//meta compare
$repeater_meta_query->add_control(
    'gbx_meta_query_meta_compare',
    [
        'label' => esc_html__('Meta Compare', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            '=' => esc_html__('=', 'gbx'),
            '!=' => esc_html__('!=', 'gbx'),
            '>' => esc_html__('>', 'gbx'),
            '>=' => esc_html__('>=', 'gbx'),
            '<' => esc_html__('<', 'gbx'),
            '<=' => esc_html__('<=', 'gbx'),
            'LIKE' => esc_html__('LIKE', 'gbx'),
            'NOT LIKE' => esc_html__('NOT LIKE', 'gbx'),
            'IN' => esc_html__('IN', 'gbx'),
            'NOT IN' => esc_html__('NOT IN', 'gbx'),
            'BETWEEN' => esc_html__('BETWEEN', 'gbx'),
            'NOT BETWEEN' => esc_html__('NOT BETWEEN', 'gbx'),
            'EXISTS' => esc_html__('EXISTS', 'gbx'),
            'NOT EXISTS' => esc_html__('NOT EXISTS', 'gbx'),
        ],
        'default' => '=',
        'condition' => [
            'gbx_meta_query_relation_or_meta_key' => 'meta_key',
        ],
    ]
);

//meta type
$repeater_meta_query->add_control(
    'gbx_meta_query_meta_type',
    [
        'label' => esc_html__('Meta Type', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'NUMERIC' => esc_html__('NUMERIC', 'gbx'),
            'BINARY' => esc_html__('BINARY', 'gbx'),
            'CHAR' => esc_html__('CHAR', 'gbx'),
            'DATE' => esc_html__('DATE', 'gbx'),
            'DATETIME' => esc_html__('DATETIME', 'gbx'),
            'DECIMAL' => esc_html__('DECIMAL', 'gbx'),
            'SIGNED' => esc_html__('SIGNED', 'gbx'),
            'TIME' => esc_html__('TIME', 'gbx'),
            'UNSIGNED' => esc_html__('UNSIGNED', 'gbx'),
        ],
        'default' => 'NUMERIC',
        'condition' => [
            'gbx_meta_query_relation_or_meta_key' => 'meta_key',
        ],
    ]
);

// repeater
$this->add_control(
    'gbx_repeater_meta_query_builder',
    [
        'label' => esc_html__('Meta Query', 'gbx'),
        'fields' => $repeater_meta_query->get_controls(),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'description' => esc_html__('Add meta query, Meta Key, Meta Value, Meta Compare, Meta Type', 'gbx'),
        'title_field' => '{{{ gbx_meta_query_relation_or_meta_key }}}',
        'prevent_empty' => false,
    ]
);

// date query builder
$repeater_date_query = new \Elementor\Repeater();

// type of date query - relation, date parameters, before and after string, before and after , column 
$repeater_date_query->add_control(
    'gbx_date_query_type',
    [
        'label' => esc_html__('Type', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'relation' => esc_html__('Relation', 'gbx'),
            'date_parameters' => esc_html__('Date Parameters', 'gbx'),
            'before_after_string' => esc_html__('Before and After', 'gbx'),
        ],
        'default' => 'relation',
    ]
);

// relation
$repeater_date_query->add_control(
    'gbx_date_query_relation',
    [
        'label' => esc_html__('Relation', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'AND' => esc_html__('AND', 'gbx'),
            'OR' => esc_html__('OR', 'gbx'),
        ],
        'default' => 'AND',
        'condition' => [
            'gbx_date_query_type' => 'relation',
        ],
    ]
);

// date parameters
$repeater_date_query->add_control(
    'gbx_date_query_year',
    [
        'label' => esc_html__('Year', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_month',
    [
        'label' => esc_html__('Month', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_week',
    [
        'label' => esc_html__('Week', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_day',
    [
        'label' => esc_html__('Day', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_hour',
    [
        'label' => esc_html__('Hour', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_minute',
    [
        'label' => esc_html__('Minute', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_second',
    [
        'label' => esc_html__('Second', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);


$repeater_date_query->add_control(
    'gbx_date_query_compare',
    [
        'label' => esc_html__('Compare', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            '=' => esc_html__('=', 'gbx'),
            '!=' => esc_html__('!=', 'gbx'),
            '>' => esc_html__('>', 'gbx'),
            '>=' => esc_html__('>=', 'gbx'),
            '<' => esc_html__('<', 'gbx'),
            '<=' => esc_html__('<=', 'gbx'),
            'LIKE' => esc_html__('LIKE', 'gbx'),
            'NOT LIKE' => esc_html__('NOT LIKE', 'gbx'),
            'IN' => esc_html__('IN', 'gbx'),
            'NOT IN' => esc_html__('NOT IN', 'gbx'),
            'BETWEEN' => esc_html__('BETWEEN', 'gbx'),
            'NOT BETWEEN' => esc_html__('NOT BETWEEN', 'gbx'),
            'EXISTS' => esc_html__('EXISTS', 'gbx'),
            'NOT EXISTS' => esc_html__('NOT EXISTS', 'gbx'),
        ],
        'default' => '=',
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);


$repeater_date_query->add_control(
    'gbx_date_query_column',
    [
        'label' => esc_html__('Column', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'post_date' => esc_html__('Post Date', 'gbx'),
            'post_date_gmt' => esc_html__('Post Date GMT', 'gbx'),
            'post_modified' => esc_html__('Post Modified', 'gbx'),
            'post_modified_gmt' => esc_html__('Post Modified GMT', 'gbx'),
            'comment_date' => esc_html__('Comment Date', 'gbx'),
            'comment_date_gmt' => esc_html__('Comment Date GMT', 'gbx'),
        ],
        'default' => 'post_date',
        'condition' => [
            'gbx_date_query_type' => 'date_parameters',
        ],
    ]
);

$repeater_date_query->add_control(
    'gbx_date_query_inclusive',
    [
        'label' => esc_html__('Inclusive', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'gbx'),
        'label_off' => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default' => 'yes',
        'condition' => [
            'gbx_date_query_type' => ['date_parameters', 'before_after_string'],
        ],
    ]
);




// before_after_string after text
$repeater_date_query->add_control(
    'gbx_date_query_before_after_string_after',
    [
        'label' => esc_html__('After', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'condition' => [
            'gbx_date_query_type' => 'before_after_string',
        ],
        'description' => 'Date to retrieve posts after',
    ]
);

// before_after_string before text
$repeater_date_query->add_control(
    'gbx_date_query_before_after_string_before',
    [
        'label' => esc_html__('Before', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'condition' => [
            'gbx_date_query_type' => 'before_after_string',
        ],
        'description' => 'Date to retrieve posts before',
    ]
);

// before_after_string before text
$repeater_date_query->add_control(
    'gbx_date_query_before_after_string_inclusive',
    [
        'label' => esc_html__('Inclusive', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'gbx'),
        'label_off' => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default' => 'yes',
        'condition' => [
            'gbx_date_query_type' => 'before_after_string',
        ],
    ]
);


// repeater end
$this->add_control(
    'gbx_date_query',
    [
        'label' => esc_html__('Date Query', 'gbx'),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater_date_query->get_controls(),
        'title_field' => '{{{ gbx_date_query_type }}}',
        'prevent_empty' => false,
    ]
);




$this->end_controls_section();
