<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}


// class and id
$repeater->add_control(
    'gbx_repeater_class',
    [
        'label' => esc_html__('Class', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => esc_html__('', 'gbx'),
        'label_block' => false,
        'description' => esc_html__('Add a class to this block', 'gbx'),
    ]
);

$repeater->add_control(
    'gbx_repeater_id',
    [
        'label' => esc_html__('ID', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => esc_html__('', 'gbx'),
        'label_block' => false,
        'description' => esc_html__('Add a id to this block', 'gbx'),
    ]
);

// z-index
$repeater->add_control(
    'gbx_repeater_z_index',
    [
        'label' => esc_html__('Z-Index', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}' => 'z-index: {{VALUE}}',
        ],
        'label_block' => false,
        'description' => esc_html__('Set the z-index of this block', 'gbx'),
    ]
);

// min-height control
$repeater->add_responsive_control(
    'gbx_repeater_min_height',
    [
        'label' => esc_html__('Min Height', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', 'vh'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1000,
                'step' => 1,
            ],
            'vh' => [
                'min' => 0,
                'max' => 100,
                'step' => 1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}' => 'min-height: {{SIZE}}{{UNIT}}',
        ],
        'label_block' => true,
        'description' => esc_html__('Set the min-height of this block', 'gbx'),
    ]
);



// enable visibilty control
$repeater->add_control(
    'enable_hover_visibility',
    [
        'label'        => esc_html__('Hover Visibility', 'gbx'),
        'type'         => \Elementor\Controls_Manager::SELECT,
        'default' => '',
        'options' => [
            '' => esc_html__('None', 'gbx'),
            'hideonhover' => esc_html__('Hide on Hover', 'gbx'),
            'showonhover' => esc_html__('Show on Hover', 'gbx'),
        ],
        'condition'  => [
            'field_type!' => ['column'],
        ],
        'description' => esc_html__('Select "None" to display the repeater item at all times, "Hide on Hover" to hide the item when the mouse pointer is over it, and "Show on Hover" to show the item when the mouse pointer is over it.', 'gbx'),
    ]
);


// enable visibilty control
$repeater->add_control(
    'enable_visibility',
    [
        'label'        => esc_html__('Enable ACF Conditional Visibility', 'gbx'),
        'type'         => \Elementor\Controls_Manager::SWITCHER,
        'label_on'     => esc_html__('Yes', 'gbx'),
        'label_off'    => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default'      => '',
        'description'  => esc_html__('To control the visibility of this field, please use ACF conditions as they are currently the only supported method.', 'gbx'),
        'condition'  => [
            'field_type!' => ['column'],
        ],
    ]
);

// show hide control
$repeater->add_control(
    'show_hide',
    [
        'label'        => esc_html__('Show/Hide, if conditions are true', 'gbx'),
        'type'         => \Elementor\Controls_Manager::SELECT,
        'default'      => 'show',
        'options'      => [
            'show' => esc_html__('Show', 'gbx'),
            'hide' => esc_html__('Hide', 'gbx'),
        ],
        'condition'  => [
            'enable_visibility' => ['yes'],
        ],
    ]
);

// one or all match control
$repeater->add_control(
    'one_or_all_match',
    [
        'label'        => esc_html__('One or All Match', 'gbx'),
        'type'         => \Elementor\Controls_Manager::SELECT,
        'default'      => 'one',
        'options'      => [
            'all' => esc_html__('All', 'gbx'),
            'one' => esc_html__('One', 'gbx'),
        ],
        'condition'  => [
            'enable_visibility' => ['yes'],
        ],
    ]
);



// acf field selector for visibility
$repeater->add_control(
    'dynamic_field',
    [
        'label'       => esc_html__('Dynamic Visibility', 'gbx'),
        'type'        => 'dynamic_field_select',
        'label_block' => false,
        'acf_fields' => GRIDBUILDERX\Utils::get_list_of_all_acf_fields(),
        'options'   => [
            'equal_to' => esc_html__('Equal To', 'gbx'),
            'not_equal_to' => esc_html__('Not Equal To', 'gbx'),
            'greater_than' => esc_html__('Greater Than', 'gbx'),
            'less_than' => esc_html__('Less Than', 'gbx'),
            'greater_than_or_equal_to' => esc_html__('Greater Than Or Equal To', 'gbx'),
            'less_than_or_equal_to' => esc_html__('Less Than Or Equal To', 'gbx'),
            'contains' => esc_html__('Contains', 'gbx'),
            'not_contains' => esc_html__('Not Contains', 'gbx'),
            'starts_with' => esc_html__('Starts With', 'gbx'),
            'ends_with' => esc_html__('Ends With', 'gbx'),
            'is_empty' => esc_html__('Is Empty', 'gbx'),
            'is_not_empty' => esc_html__('Is Not Empty', 'gbx'),
        ],
        'condition'  => [
            'enable_visibility' => ['yes'],
        ],
    ]
);
