<?php
if (!defined('ABSPATH')) {
    exit;
}

//headline control 
$repeater->add_control(
    'headline_images',
    [
        'label' => esc_html__('Image Hover Settings', 'gbx'),
        'type' => \Elementor\Controls_Manager::HEADING,
        'separator' => 'before',
        'condition'  => [
            'field_type' => 'image',
        ],
    ]
);

// image hover background group control
$repeater->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name' => 'gbx_repeater_image_hover_background_group',
        'label' => esc_html__('Image Hover Background', 'gbx'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}:hover .gbx-overlay-image',
        'label_block' => false,
        'description' => esc_html__('Set the background hover of this block', 'gbx'),
        'condition'  => [
            'field_type' => 'image',
        ],
        'default' => null,
    ]
);

// opacity
$repeater->add_control(
    'gbx_repeater_image_hover_opacity',
    [
        'label' => esc_html__('Image Hover Opacity', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
            ],
        ],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover .gbx-overlay-image' => 'opacity: {{SIZE}};',
        ],
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the opacity of this block', 'gbx'),
        'condition'  => [
            'field_type' => 'image',
        ],
    ]
);


// hover border radius for image
$repeater->add_responsive_control(
    'gbx_repeater_image_hover_radius',
    [
        'label' => esc_html__('Image Hover Radius', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the border hover radius of this block', 'gbx'),
        'condition'  => [
            'field_type' => 'image',
        ],
    ]
);



// hover border width for image
$repeater->add_responsive_control(
    'gbx_repeater_image_hover_width',
    [
        'label' => esc_html__('Image Hover Width', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover img' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the border hover width of this block', 'gbx'),
        'condition'  => [
            'field_type' => 'image',
        ],
    ]
);

//opacity


// hover border style for image
$repeater->add_control(
    'gbx_repeater_image_hover_style',
    [
        'label' => esc_html__('Image Hover Style', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => null,
        'options' => [
            'solid' => esc_html__('Solid', 'gbx'),
            'dashed' => esc_html__('Dashed', 'gbx'),
            'dotted' => esc_html__('Dotted', 'gbx'),
            'double' => esc_html__('Double', 'gbx'),
            'none' => esc_html__('None', 'gbx'),
        ],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover img' => 'border-style: {{VALUE}};',
        ],
        'label_block' => true,
        'description' => esc_html__('Set the border hover style of this block', 'gbx'),
        'condition'  => [
            'field_type' => 'image',
        ],
    ]
);

// shadow hover for image
$repeater->add_group_control(
    \Elementor\Group_Control_Box_Shadow::get_type(),
    [
        'name' => 'gbx_repeater_image_shadow_hover',
        'label' => esc_html__('Image Shadow Hover', 'gbx'),
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}:hover img',
        'label_block' => false,
        'description' => esc_html__('Set the shadow hover of this block', 'gbx'),
        'condition'  => [
            'field_type' => 'image',
        ],
        'default' => null,

    ]
);


// button specific hover settings
$repeater->add_control(
    'headline_button',
    [
        'label' => esc_html__('Button Hover Settings', 'gbx'),
        'type' => \Elementor\Controls_Manager::HEADING,
        'separator' => 'before',
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button font hover color
$repeater->add_control(
    'gbx_repeater_button_hover_color',
    [
        'label' => esc_html__('Button Hover Color', 'gbx'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'color: {{VALUE}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the font hover color of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button hover background color with classic and gradient
$repeater->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name' => 'gbx_repeater_button_hover_background',
        'label' => esc_html__('Button Hover Background', 'gbx'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} a:hover',
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the background hover color of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button hover typography
$repeater->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
        'name' => 'gbx_repeater_button_hover_typography',
        'label' => esc_html__('Button Hover Typography', 'gbx'),
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} a:hover',
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the typography hover of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);


// button hover border radius
$repeater->add_responsive_control(
    'gbx_repeater_button_hover_radius',
    [
        'label' => esc_html__('Button Hover Radius', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the border hover radius of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button hover border color
$repeater->add_control(
    'gbx_repeater_button_hover_border_color',
    [
        'label' => esc_html__('Button Hover Border Color', 'gbx'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'border-color: {{VALUE}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the border hover color of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button hover border style
$repeater->add_control(
    'gbx_repeater_button_hover_border_style',
    [
        'label' => esc_html__('Button Hover Border Style', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'solid' => esc_html__('Solid', 'gbx'),
            'dashed' => esc_html__('Dashed', 'gbx'),
            'dotted' => esc_html__('Dotted', 'gbx'),
            'double' => esc_html__('Double', 'gbx'),
            'none' => esc_html__('None', 'gbx'),
        ],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'border-style: {{VALUE}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the border hover style of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);



// button hover border width
$repeater->add_responsive_control(
    'gbx_repeater_button_hover_width',
    [
        'label' => esc_html__('Button Hover Width', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the border hover width of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button hover padding
$repeater->add_responsive_control(
    'gbx_repeater_button_hover_padding',
    [
        'label' => esc_html__('Button Hover Padding', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the padding hover of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// buttton hover margin
$repeater->add_responsive_control(
    'gbx_repeater_button_hover_margin',
    [
        'label' => esc_html__('Button Hover Margin', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the margin hover of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);

// button hover box shadow
$repeater->add_group_control(
    \Elementor\Group_Control_Box_Shadow::get_type(),
    [
        'name' => 'gbx_repeater_button_hover_box_shadow',
        'label' => esc_html__('Button Hover Box Shadow', 'gbx'),
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} a:hover',
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the box shadow hover of this block', 'gbx'),
        'condition' => [
            'field_type' => 'button',
        ],
    ]
);



// font hover color
$repeater->add_control(
    'gbx_repeater_font_hover_color',
    [
        'label' => esc_html__('Font Hover Color', 'gbx'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'color: {{VALUE}}',
            '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'color: {{VALUE}}',
        ],
        'label_block' => false,
        'default' => null,
        'description' => esc_html__('Set the font hover color of this block', 'gbx'),
        'condition' => [
            'field_type' => ['text', 'button', 'meta'],
        ],
    ]
);


// background image, color, gradient
$repeater->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name'     => 'gbx_repeater_background_hover_color',
        'label'    => esc_html__('Background', 'gbx'),
        'types'    => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}:hover',
    ]
);


// background image, color, gradient
$repeater->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name'     => 'gbx_repeater_background_hover_color_container',
        'label'    => esc_html__('Container Background', 'gbx'),
        'types'    => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .gbx-repeater-item-inner:hover',
    ]
);


//hover typography
$repeater->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
        'name' => 'gbx_repeater_hover_typography',
        'label' => esc_html__('Typography', 'gbx'),
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}:hover',
        'description' => esc_html__('Set the typography of this block', 'gbx'),
        'condition' => [
            'field_type!' => ['column'],
        ],
    ]
);



// borger hover group control
$repeater->add_group_control(
    \Elementor\Group_Control_Border::get_type(),
    [
        'name' => 'gbx_repeater_border_hover_group',
        'label' => esc_html__('Border', 'gbx'),
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}:hover',
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the border hover of this block', 'gbx'),
    ]
);

// border hover border radius
$repeater->add_responsive_control(
    'gbx_repeater_border_hover_radius',
    [
        'label' => esc_html__('Border Hover Radius', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the border hover radius of this block', 'gbx'),
    ]
);


// borger hover group control
$repeater->add_group_control(
    \Elementor\Group_Control_Border::get_type(),
    [
        'name' => 'gbx_repeater_border_hover_group_container',
        'label' => esc_html__('Border', 'gbx'),
        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .gbx-repeater-item-inner:hover',
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the border hover of this block', 'gbx'),
    ]
);

// border hover border radius
$repeater->add_responsive_control(
    'gbx_repeater_border_hover_radius_container',
    [
        'label' => esc_html__('Border Hover Radius', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}} .gbx-repeater-item-inner:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'label_block' => true,
        'default' => null,
        'description' => esc_html__('Set the border hover radius of this block', 'gbx'),
    ]
);



// hover animation - select moveUp , pulse
$repeater->add_control(
    'gbx_repeater_hover_animation_animation',
    [
        'label' => esc_html__('Hover Animation', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '',
        'options' => [
            '' => esc_html__('None', 'gbx'),
            'moveUp' => esc_html__('Move Up', 'gbx'),
            'moveDown' => esc_html__('Move Down', 'gbx'),
            'pulse' => esc_html__('Pulse', 'gbx'),
            'bounce' => esc_html__('Bounce', 'gbx'),
            'flash' => esc_html__('Flash', 'gbx'),
            'headShake' => esc_html__('Head Shake', 'gbx'),
            'swing' => esc_html__('Swing', 'gbx'),
            'tada' => esc_html__('Tada', 'gbx'),
            'wobble' => esc_html__('Wobble', 'gbx'),
            'jello' => esc_html__('Jello', 'gbx'),
        ],
        'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'animation-name: {{VALUE}};',
        ],
    ]
);
