<?php

// if accessed directly than exit
if (!defined('ABSPATH')) {
    exit;
}

$this->start_controls_section(
    'gbx_grids_designer',
    [
        'label' => esc_html__('Grids Designer', 'gbx'),
    ]
);


$this->start_controls_tabs(
    'gbx_grid_style_tabs'
);

$this->start_controls_tab(
    'gbx_grid_style_layout_tab',
    [
        'label' => esc_html__('Layout', 'gbx'),
    ]
);


$this->add_responsive_control(
    'gbx_grid_column_count',
    [
        'label' => esc_html__('Column count by device', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 100,
        'step' => 1,
        'default' => 4,
        'description' => esc_html__('This is responsive control. Click on icon next to this field to change the column count for other devices', 'gbx'),
        'selectors' => [
            '{{WRAPPER}} .gbx-grids' => 'grid-template-columns: repeat({{VALUE}}, 1fr);',
        ],
    ]
);

$this->add_responsive_control(
    'gbx_grid_gap_horizontal',
    [
        'label' => esc_html__('Column Gap', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 1000,
        'step' => 1,
        'default' => 20,
        'description' => esc_html__('This is responsive control. Click on icon next to this field to change the column count for other devices', 'gbx'),
        'selectors' => [
            '{{WRAPPER}} .gbx-grids' => 'grid-column-gap: {{VALUE}}px;',
        ],
    ]
);

$this->add_responsive_control(
    'gbx_grid_gap_vertical',
    [
        'label' => esc_html__('Row Gap', 'gbx'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 1000,
        'step' => 1,
        'default' => 20,
        'description' => esc_html__('This is responsive control. Click on icon next to this field to change the column count for other devices', 'gbx'),
        'selectors' => [
            '{{WRAPPER}} .gbx-grids' => 'grid-row-gap: {{VALUE}}px;',
        ],
    ]
);

// enable the clickable grid
$this->add_control(
    'gbx_grid_clickable',
    [
        'label' => esc_html__('Clickable Grid', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'gbx'),
        'label_off' => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default' => 'no',
    ]
);

// No more posts message
$this->add_control(
    'gbx_grid_no_more_posts_message',
    [
        'label' => esc_html__('No more posts message', 'gbx'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => esc_html__('No more posts to show', 'gbx'),
    ]
);

// No more post color
$this->add_control(
    'gbx_grid_no_more_posts_message_color',
    [
        'label' => esc_html__('No more posts message color', 'gbx'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => '#000000',
        'selectors' => [
            '{{WRAPPER}} .gbx .gbx-no-moreitems' => 'color: {{VALUE}};',
        ],
    ]
);

// Background color
$this->add_control(
    'gbx_grid_background_color',
    [
        'label' => esc_html__('Background Color', 'gbx'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => '#ffffff',
        'selectors' => [
            '{{WRAPPER}} .gbx .gbx-no-moreitems' => 'background-color: {{VALUE}};',
        ],
    ]
);



// Alignment
$this->add_control(
    'gbx_grid_alignment',
    [
        'label' => esc_html__('Alignment', 'gbx'),
        'type' => \Elementor\Controls_Manager::CHOOSE,
        'options' => [
            'left' => [
                'title' => esc_html__('Left', 'gbx'),
                'icon' => 'fa fa-align-left',
            ],
            'center' => [
                'title' => esc_html__('Center', 'gbx'),
                'icon' => 'fa fa-align-center',
            ],
            'right' => [
                'title' => esc_html__('Right', 'gbx'),
                'icon' => 'fa fa-align-right',
            ],
        ],
        'default' => 'center',
        'toggle' => true,
        'selectors' => [
            '{{WRAPPER}} .gbx .gbx-no-moreitems' => 'text-align: {{VALUE}};',
        ],
    ]
);




// link target
$this->add_control(
    'gbx_grid_link_target',
    [
        'label' => esc_html__('Link Target', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            '_self' => esc_html__('Same Tab', 'gbx'),
            '_blank' => esc_html__('New Tab', 'gbx'),
        ],
        'default' => '_self',
        'condition' => [
            'gbx_grid_clickable' => 'yes'
        ]
    ]
);

// link type
$this->add_control(
    'gbx_grid_link_type',
    [
        'label' => esc_html__('Link Type', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            'post' => esc_html__('Post', 'gbx'),
            'custom' => esc_html__('Custom', 'gbx'),
            'acf' => esc_html__('ACF', 'gbx'),
        ],
        'default' => 'post',
        'condition' => [
            'gbx_grid_clickable' => 'yes'
        ]
    ]
);

// custom link
$this->add_control(
    'gbx_grid_custom_link',
    [
        'label' => esc_html__('Custom Link', 'gbx'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'gbx'),
        'show_external' => true,
        'default' => [
            'url' => '',
            'is_external' => true,
            'nofollow' => true,
        ],
        'condition' => [
            'gbx_grid_clickable' => 'yes',
            'gbx_grid_link_type' => 'custom'
        ]
    ]
);

// acf link : \GRIDBUILDERX\Utils::get_list_of_all_acf_fields()
$this->add_control(
    'gbx_grid_acf_link',
    [
        'label' => esc_html__('ACF Link', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => \GRIDBUILDERX\Utils::get_list_of_all_acf_fields(),
        'default' => '',
        'condition' => [
            'gbx_grid_clickable' => 'yes',
            'gbx_grid_link_type' => 'acf'
        ]
    ]
);


$this->end_controls_tab();


$this->start_controls_tab(
    'gbx_grid_style_normal_tab',
    [
        'label' => esc_html__('Styling', 'gbx'),
    ]
);


$this->add_control(
    'gbx_grid_background_type',
    [
        'label' => esc_html__('Background Type', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            'none'  => esc_html__('None', 'gbx'),
            'color'  => esc_html__('Color, Image or Gradient', 'gbx'),
            'featuredimage' => esc_html__('Featured Image', 'gbx'),
            'acf' => esc_html__('ACF Field', 'gbx'),
        ],
        'default' => ['none'],
    ]
);

// acf field selector use utils ti get all acf fields
$this->add_control(
    'gbx_grid_background_custom_field',
    [
        'label' => esc_html__('ACF Field', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => \GRIDBUILDERX\Utils::get_list_of_all_acf_fields(),
        'default' => ['none'],
        'condition' => [
            'gbx_grid_background_type' => ['acf'],
        ],
    ]
);



$this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name' => 'gbx_grids_background_setter',
        'label' => esc_html__('Background', 'gbx'),
        'types' => ['classic', 'gradient',],
        'selector' => '{{WRAPPER}} .gbx__item',
        'condition' => [
            'gbx_grid_background_type' => ['color'],
        ],
    ]
);

// placed holder image if no featured image
$this->add_control(
    'gbx_grid_background_placeholder',
    [
        'label' => esc_html__('Placeholder Image', 'gbx'),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
            'url' => \Elementor\Utils::get_placeholder_image_src(),
        ],
        'condition' => [
            'gbx_grid_background_type' => ['featuredimage', 'acf'],
        ],
    ]
);


// background image size selector , dimensions
$this->add_group_control(
    \Elementor\Group_Control_Image_Size::get_type(),
    [
        'name' => 'gbx_grid_background_placeholder',
        'default' => 'full',
        'condition' => [
            'gbx_grid_background_type' => ['acf', 'featuredimage'],
        ],
    ]
);

// background position
$this->add_control(
    'gbx_grid_background_position',
    [
        'label' => esc_html__('Background Position', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            'center center' => esc_html__('Center Center', 'gbx'),
            'center left' => esc_html__('Center Left', 'gbx'),
            'center right' => esc_html__('Center Right', 'gbx'),
            'top center' => esc_html__('Top Center', 'gbx'),
            'top left' => esc_html__('Top Left', 'gbx'),
            'top right' => esc_html__('Top Right', 'gbx'),
            'bottom center' => esc_html__('Bottom Center', 'gbx'),
            'bottom left' => esc_html__('Bottom Left', 'gbx'),
            'bottom right' => esc_html__('Bottom Right', 'gbx'),
        ],
        'default' => 'center center',
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'background-position: {{VALUE}};',
        ],
        'condition' => [
            'gbx_grid_background_type' => ['featuredimage', 'acf'],
        ],
    ]
);

// background repeat
$this->add_control(
    'gbx_grid_background_repeat',
    [
        'label' => esc_html__('Background Repeat', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            'no-repeat' => esc_html__('No Repeat', 'gbx'),
            'repeat' => esc_html__('Repeat', 'gbx'),
            'repeat-x' => esc_html__('Repeat X', 'gbx'),
            'repeat-y' => esc_html__('Repeat Y', 'gbx'),
        ],
        'default' => 'no-repeat',
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'background-repeat: {{VALUE}};',
        ],
        'condition' => [
            'gbx_grid_background_type' => ['featuredimage', 'acf'],
        ],
    ]
);

// background size
$this->add_control(
    'gbx_grid_background_size',
    [
        'label' => esc_html__('Background Size', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            'auto' => esc_html__('Auto', 'gbx'),
            'cover' => esc_html__('Cover', 'gbx'),
            'contain' => esc_html__('Contain', 'gbx'),
        ],
        'default' => 'auto',
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'background-size: {{VALUE}};',
        ],
        'condition' => [
            'gbx_grid_background_type' => ['featuredimage', 'acf'],
        ],
    ]
);

// background attachment
$this->add_control(
    'gbx_grid_background_attachment',
    [
        'label' => esc_html__('Background Attachment', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'options' => [
            'scroll' => esc_html__('Scroll', 'gbx'),
            'fixed' => esc_html__('Fixed', 'gbx'),
        ],
        'default' => 'scroll',
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'background-attachment: {{VALUE}};',
        ],
        'condition' => [
            'gbx_grid_background_type' => ['featuredimage', 'acf'],
        ],
    ]
);




//enable overlay
$this->add_control(
    'gbx_grids_enable_overlay',
    [
        'label' => esc_html__('Enable Overlay', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'gbx'),
        'label_off' => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default' => 'no',
        'condition' => [
            'gbx_grid_background_type' => ['color', 'featuredimage', 'acf'],
        ],
    ]
);

// overlay background image and gradient
$this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name' => 'gbx_grids_overlay_background_setter',
        'label' => esc_html__('Overlay Background', 'gbx'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .gbx__item::before',
        'condition' => [
            'gbx_grids_enable_overlay' => 'yes',
        ],
    ]
);

//opacity slider
$this->add_control(
    'gbx_grids_overlay_opacity',
    [
        'label' => esc_html__('Overlay Opacity', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 0.5,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item::before' => 'opacity: {{SIZE}};',
        ],
        'condition' => [
            'gbx_grids_enable_overlay' => 'yes',
        ],
    ]
);


// glassmorphism
$this->add_control(
    'gbx_grids_glassmorphism_blur',
    [
        'label' => esc_html__('Glassmorphism Blur', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 100,
                'step' => 1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 20,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item::before' => 'filter: blur({{SIZE}}px);',

        ],
        'condition' => [
            'gbx_grids_enable_overlay' => 'yes',
        ],
    ]
);

// scale
$this->add_control(
    'gbx_grids_scale',
    [
        'label' => esc_html__('Glassmorphism Scale', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 1.3,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item::before' => 'transform: scale({{SIZE}});',
        ],
        'condition' => [
            'gbx_grids_enable_overlay' => 'yes',
        ],
    ]
);



// min height
$this->add_responsive_control(
    'gbx_grids_min_height',
    [
        'label' => esc_html__('Min Height', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1000,
                'step' => 1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 0,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'min-height: {{SIZE}}{{UNIT}};',
        ],
    ]
);

// align items content - flex align-content
$this->add_responsive_control(
    'gbx_grids_align_content',
    [
        'label' => esc_html__('Vertical Align', 'gbx'),
        'type' => \Elementor\Controls_Manager::CHOOSE,
        'options' => [
            'flex-start' => [
                'title' => esc_html__('Top', 'gbx'),
                'icon' => 'eicon-v-align-top',
            ],
            'center' => [
                'title' => esc_html__('Center', 'gbx'),
                'icon' => 'eicon-v-align-middle',
            ],
            'flex-end' => [
                'title' => esc_html__('Bottom', 'gbx'),
                'icon' => 'eicon-v-align-bottom',
            ],
            'space-between' => [
                'title' => esc_html__('Space Between', 'gbx'),
                'icon' => 'eicon-v-align-stretch',
            ],
            'space-around' => [
                'title' => esc_html__('Space Around', 'gbx'),
                'icon' => 'eicon-v-align-stretch',
            ],
            'space-evenly' => [
                'title' => esc_html__('Space Evenly', 'gbx'),
                'icon' => 'eicon-v-align-stretch',
            ],
        ],
        'default' => 'flex-start',
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'align-content: {{VALUE}};',
        ],
    ]
);


// justify content
$this->add_responsive_control(
    'gbx_grids_justify_content',
    [
        'label' => esc_html__('Horizontal Align', 'gbx'),
        'type' => \Elementor\Controls_Manager::CHOOSE,
        'options' => [
            'flex-start' => [
                'title' => esc_html__('Left', 'gbx'),
                'icon' => 'eicon-h-align-left',
            ],
            'center' => [
                'title' => esc_html__('Center', 'gbx'),
                'icon' => 'eicon-h-align-center',
            ],
            'flex-end' => [
                'title' => esc_html__('Right', 'gbx'),
                'icon' => 'eicon-h-align-right',
            ],
        ],

        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'justify-content: {{VALUE}};',
        ],
    ]
);

// margin
$this->add_responsive_control(
    'gbx_grids_margin',
    [
        'label' => esc_html__('Margin', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
    ]
);

// padding
$this->add_responsive_control(
    'gbx_grids_padding',
    [
        'label' => esc_html__('Padding', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
    ]
);


//border
$this->add_group_control(
    \Elementor\Group_Control_Border::get_type(),
    [
        'name' => 'gbx_grids_border',
        'label' => esc_html__('Border', 'gbx'),
        'selector' => '{{WRAPPER}} .gbx__item',
    ]
);

// border radius
$this->add_control(
    'gbx_grids_border_radius',
    [
        'label' => esc_html__('Border Radius', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} .gbx__item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
    ]
);

// box shadow
$this->add_group_control(
    \Elementor\Group_Control_Box_Shadow::get_type(),
    [
        'name' => 'gbx_grids_box_shadow',
        'label' => esc_html__('Box Shadow', 'gbx'),
        'selector' => '{{WRAPPER}} .gbx__item',
    ]
);

$this->end_controls_tab();

$this->start_controls_tab(
    'gbx_style_hover_tab',
    [
        'label' => esc_html__('Hover', 'gbx'),
    ]
);

// hover background image and gradient
$this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name' => 'gbx_grids_hover_background_setter',
        'label' => esc_html__('Hover Background', 'gbx'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .gbx__item:hover',
    ]
);

// grid item scale on hover
$this->add_control(
    'gbx_grids_hover_scale_grids',
    [
        'label' => esc_html__('Scale', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'range' => [
            'px' => [
                'min' => 0.8,
                'max' => 1.5,
                'step' => 0.01,
            ],
        ],
        'default' => [
            'size' => 1,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx-outer:hover' => 'transform: scale({{SIZE}});',
        ],
    ]
);

// hover overlay
$this->add_control(
    'gbx_grids_hover_enable_overlay',
    [
        'label' => esc_html__('Enable Hover Overlay', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'gbx'),
        'label_off' => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default' => 'no',
    ]
);

// hover overlay background GRoup control background
$this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
        'name' => 'gbx_grids_hover_overlay_background_setter',
        'label' => esc_html__('Hover Overlay Background', 'gbx'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .gbx__item:hover::before',
        'condition' => [
            'gbx_grids_hover_enable_overlay' => 'yes',
        ],
    ]
);

// hover glassmorphism
$this->add_control(
    'gbx_grids_hover_enable_glassmorphism',
    [
        'label' => esc_html__('Enable Hover Glassmorphism', 'gbx'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'gbx'),
        'label_off' => esc_html__('No', 'gbx'),
        'return_value' => 'yes',
        'default' => 'no',
        'condition' => [
            'gbx_grids_hover_enable_overlay' => 'yes',
        ],
    ]
);

// hover glassmorphism blur
$this->add_control(
    'gbx_grids_hover_glassmorphism_blur',
    [
        'label' => esc_html__('Hover Glassmorphism Blur', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 100,
                'step' => 1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 20,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover::before' => 'filter: blur({{SIZE}}{{UNIT}});',
        ],
        'condition' => [
            'gbx_grids_hover_enable_glassmorphism' => 'yes',
        ],
    ]
);

// hover glassmorphism scale
$this->add_control(
    'gbx_grids_hover_glassmorphism_scale',
    [
        'label' => esc_html__('Hover Glassmorphism Scale', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 1.1,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover::before' => 'transform: scale({{SIZE}});',
        ],
        'condition' => [
            'gbx_grids_hover_enable_glassmorphism' => 'yes',
        ],
    ]
);


// hover overlay opacity
$this->add_control(
    'gbx_grids_hover_overlay_opacity',
    [
        'label' => esc_html__('Hover Overlay Opacity', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 0.5,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover::before' => 'opacity: {{SIZE}};',
        ],
        'condition' => [
            'gbx_grids_hover_enable_overlay' => 'yes',
        ],
    ]
);

// hover overlay scale
$this->add_control(
    'gbx_grids_hover_scale',
    [
        'label' => esc_html__('Hover Scale', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 1.3,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover::before' => 'transform: scale({{SIZE}});',
        ],
        'condition' => [
            'gbx_grids_hover_enable_overlay' => 'yes',
        ],
    ]
);

//hover grid scale


// hover border
$this->add_group_control(
    \Elementor\Group_Control_Border::get_type(),
    [
        'name' => 'gbx_grids_hover_border',
        'label' => esc_html__('Hover Border', 'gbx'),
        'selector' => '{{WRAPPER}} .gbx__item:hover',
    ]
);

// hover border radius
$this->add_control(
    'gbx_grids_hover_border_radius',
    [
        'label' => esc_html__('Hover Border Radius', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
    ]
);

// hover box shadow
$this->add_group_control(
    \Elementor\Group_Control_Box_Shadow::get_type(),
    [
        'name' => 'gbx_grids_hover_box_shadow',
        'label' => esc_html__('Hover Box Shadow', 'gbx'),
        'selector' => '{{WRAPPER}} .gbx__item:hover',
    ]
);



// hover transition
$this->add_control(
    'gbx_grids_hover_transition',
    [
        'label' => esc_html__('Hover Transition', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 0.3,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'transition: all {{SIZE}}s ease-in-out;',
        ],
    ]
);

// hover cursor
$this->add_control(
    'gbx_grids_hover_cursor',
    [
        'label' => esc_html__('Hover Cursor', 'gbx'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'dafault',
        'options' => [
            'pointer' => esc_html__('Pointer', 'gbx'),
            'default' => esc_html__('Default', 'gbx'),
            'none' => esc_html__('None', 'gbx'),
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'cursor: {{VALUE}};',
        ],
    ]
);


// hover animation duration
$this->add_control(
    'gbx_grids_hover_animation_duration',
    [
        'label' => esc_html__('Hover Animation Duration', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 0.3,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'transition: all {{SIZE}}s ease-in-out;',
        ],
    ]
);


// hover animation delay
$this->add_control(
    'gbx_grids_hover_animation_delay',
    [
        'label' => esc_html__('Hover Animation Delay', 'gbx'),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => ['px', '%', 'em'],
        'range' => [
            'px' => [
                'min' => 0,
                'max' => 2,
                'step' => 0.1,
            ],
        ],
        'default' => [
            'unit' => 'px',
            'size' => 0.3,
        ],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'transition: all {{SIZE}}s ease-in-out;',
        ],
    ]
);



// hover margin
$this->add_responsive_control(
    'gbx_grids_hover_margin',
    [
        'label' => esc_html__('Hover Margin', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
    ]
);

// hover padding
$this->add_responsive_control(
    'gbx_grids_hover_padding',
    [
        'label' => esc_html__('Hover Padding', 'gbx'),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
            '{{WRAPPER}} .gbx__item:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
    ]
);




$this->end_controls_tab();

$this->end_controls_tabs();




$this->end_controls_section();
